"""
Python module generated from Java source file java.lang.reflect.Field

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.reflect import *
from java.util import Objects
from jdk.internal.access import SharedSecrets
from jdk.internal.reflect import CallerSensitive
from jdk.internal.reflect import FieldAccessor
from jdk.internal.reflect import Reflection
from jdk.internal.vm.annotation import ForceInline
from sun.reflect.annotation import AnnotationParser
from sun.reflect.annotation import AnnotationSupport
from sun.reflect.annotation import TypeAnnotation
from sun.reflect.annotation import TypeAnnotationParser
from sun.reflect.generics.factory import CoreReflectionFactory
from sun.reflect.generics.factory import GenericsFactory
from sun.reflect.generics.repository import FieldRepository
from sun.reflect.generics.scope import ClassScope
from typing import Any, Callable, Iterable, Tuple


class Field(AccessibleObject, Member):
    """
    A `Field` provides information about, and dynamic access to, a
    single field of a class or an interface.  The reflected field may
    be a class (static) field or an instance field.
    
    A `Field` permits widening conversions to occur during a get or
    set access operation, but throws an `IllegalArgumentException` if a
    narrowing conversion would occur.

    Author(s)
    - Nakul Saraiya

    See
    - java.lang.Class.getDeclaredField(String)

    Since
    - 1.1
    """

    def setAccessible(self, flag: bool) -> None:
        """
        Raises
        - InaccessibleObjectException: 
        - SecurityException: 
        """
        ...


    def getDeclaringClass(self) -> type[Any]:
        """
        Returns the `Class` object representing the class or interface
        that declares the field represented by this `Field` object.
        """
        ...


    def getName(self) -> str:
        """
        Returns the name of the field represented by this `Field` object.
        """
        ...


    def getModifiers(self) -> int:
        """
        Returns the Java language modifiers for the field represented
        by this `Field` object, as an integer. The `Modifier` class should
        be used to decode the modifiers.

        See
        - Modifier

        Unknown Tags
        - 8.3 Field Declarations
        - 9.3 Field (Constant) Declarations
        """
        ...


    def isEnumConstant(self) -> bool:
        """
        Returns `True` if this field represents an element of
        an enumerated class; returns `False` otherwise.

        Returns
        - `True` if and only if this field represents an element of
        an enumerated class.

        Since
        - 1.5

        Unknown Tags
        - 8.9.1 Enum Constants
        """
        ...


    def isSynthetic(self) -> bool:
        """
        Returns `True` if this field is a synthetic
        field; returns `False` otherwise.

        Returns
        - True if and only if this field is a synthetic
        field as defined by the Java Language Specification.

        See
        - <a
        href="/java.base/java/lang/reflect/package-summary.html.LanguageJvmModel">Java
        programming language and JVM modeling in core reflection</a>

        Since
        - 1.5
        """
        ...


    def getType(self) -> type[Any]:
        """
        Returns a `Class` object that identifies the
        declared type for the field represented by this
        `Field` object.

        Returns
        - a `Class` object identifying the declared
        type of the field represented by this object
        """
        ...


    def getGenericType(self) -> "Type":
        """
        Returns a `Type` object that represents the declared type for
        the field represented by this `Field` object.
        
        If the declared type of the field is a parameterized type,
        the `Type` object returned must accurately reflect the
        actual type arguments used in the source code.
        
        If the type of the underlying field is a type variable or a
        parameterized type, it is created. Otherwise, it is resolved.

        Returns
        - a `Type` object that represents the declared type for
            the field represented by this `Field` object

        Raises
        - GenericSignatureFormatError: if the generic field
            signature does not conform to the format specified in
            <cite>The Java Virtual Machine Specification</cite>
        - TypeNotPresentException: if the generic type
            signature of the underlying field refers to a non-existent
            class or interface declaration
        - MalformedParameterizedTypeException: if the generic
            signature of the underlying field refers to a parameterized type
            that cannot be instantiated for any reason

        Since
        - 1.5
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Compares this `Field` against the specified object.  Returns
        True if the objects are the same.  Two `Field` objects are the same if
        they were declared by the same class and have the same name
        and type.
        """
        ...


    def hashCode(self) -> int:
        """
        Returns a hashcode for this `Field`.  This is computed as the
        exclusive-or of the hashcodes for the underlying field's
        declaring class name and its name.
        """
        ...


    def toString(self) -> str:
        """
        Returns a string describing this `Field`.  The format is
        the access modifiers for the field, if any, followed
        by the field type, followed by a space, followed by
        the fully-qualified name of the class declaring the field,
        followed by a period, followed by the name of the field.
        For example:
        ```
           public static final int java.lang.Thread.MIN_PRIORITY
           private int java.io.FileDescriptor.fd
        ```
        
        The modifiers are placed in canonical order as specified by
        "The Java Language Specification".  This is `public`,
        `protected` or `private` first, and then other
        modifiers in the following order: `static`, `final`,
        `transient`, `volatile`.

        Returns
        - a string describing this `Field`

        Unknown Tags
        - 8.3.1 Field Modifiers
        """
        ...


    def toGenericString(self) -> str:
        """
        Returns a string describing this `Field`, including
        its generic type.  The format is the access modifiers for the
        field, if any, followed by the generic field type, followed by
        a space, followed by the fully-qualified name of the class
        declaring the field, followed by a period, followed by the name
        of the field.
        
        The modifiers are placed in canonical order as specified by
        "The Java Language Specification".  This is `public`,
        `protected` or `private` first, and then other
        modifiers in the following order: `static`, `final`,
        `transient`, `volatile`.

        Returns
        - a string describing this `Field`, including
        its generic type

        Since
        - 1.5

        Unknown Tags
        - 8.3.1 Field Modifiers
        """
        ...


    def get(self, obj: "Object") -> "Object":
        """
        Returns the value of the field represented by this `Field`, on
        the specified object. The value is automatically wrapped in an
        object if it has a primitive type.
        
        The underlying field's value is obtained as follows:
        
        If the underlying field is a static field, the `obj` argument
        is ignored; it may be null.
        
        Otherwise, the underlying field is an instance field.  If the
        specified `obj` argument is null, the method throws a
        `NullPointerException`. If the specified object is not an
        instance of the class or interface declaring the underlying
        field, the method throws an `IllegalArgumentException`.
        
        If this `Field` object is enforcing Java language access control, and
        the underlying field is inaccessible, the method throws an
        `IllegalAccessException`.
        If the underlying field is static, the class that declared the
        field is initialized if it has not already been initialized.
        
        Otherwise, the value is retrieved from the underlying instance
        or static field.  If the field has a primitive type, the value
        is wrapped in an object before being returned, otherwise it is
        returned as is.
        
        If the field is hidden in the type of `obj`,
        the field's value is obtained according to the preceding rules.

        Arguments
        - obj: object from which the represented field's value is
        to be extracted

        Returns
        - the value of the represented field in object
        `obj`; primitive values are wrapped in an appropriate
        object before being returned

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is inaccessible.
        - IllegalArgumentException: if the specified object is not an
                     instance of the class or interface declaring the underlying
                     field (or a subclass or implementor thereof).
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.
        """
        ...


    def getBoolean(self, obj: "Object") -> bool:
        """
        Gets the value of a static or instance `boolean` field.

        Arguments
        - obj: the object to extract the `boolean` value
        from

        Returns
        - the value of the `boolean` field

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is inaccessible.
        - IllegalArgumentException: if the specified object is not
                     an instance of the class or interface declaring the
                     underlying field (or a subclass or implementor
                     thereof), or if the field value cannot be
                     converted to the type `boolean` by a
                     widening conversion.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.get
        """
        ...


    def getByte(self, obj: "Object") -> int:
        """
        Gets the value of a static or instance `byte` field.

        Arguments
        - obj: the object to extract the `byte` value
        from

        Returns
        - the value of the `byte` field

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is inaccessible.
        - IllegalArgumentException: if the specified object is not
                     an instance of the class or interface declaring the
                     underlying field (or a subclass or implementor
                     thereof), or if the field value cannot be
                     converted to the type `byte` by a
                     widening conversion.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.get
        """
        ...


    def getChar(self, obj: "Object") -> str:
        """
        Gets the value of a static or instance field of type
        `char` or of another primitive type convertible to
        type `char` via a widening conversion.

        Arguments
        - obj: the object to extract the `char` value
        from

        Returns
        - the value of the field converted to type `char`

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is inaccessible.
        - IllegalArgumentException: if the specified object is not
                     an instance of the class or interface declaring the
                     underlying field (or a subclass or implementor
                     thereof), or if the field value cannot be
                     converted to the type `char` by a
                     widening conversion.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.get
        """
        ...


    def getShort(self, obj: "Object") -> int:
        """
        Gets the value of a static or instance field of type
        `short` or of another primitive type convertible to
        type `short` via a widening conversion.

        Arguments
        - obj: the object to extract the `short` value
        from

        Returns
        - the value of the field converted to type `short`

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is inaccessible.
        - IllegalArgumentException: if the specified object is not
                     an instance of the class or interface declaring the
                     underlying field (or a subclass or implementor
                     thereof), or if the field value cannot be
                     converted to the type `short` by a
                     widening conversion.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.get
        """
        ...


    def getInt(self, obj: "Object") -> int:
        """
        Gets the value of a static or instance field of type
        `int` or of another primitive type convertible to
        type `int` via a widening conversion.

        Arguments
        - obj: the object to extract the `int` value
        from

        Returns
        - the value of the field converted to type `int`

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is inaccessible.
        - IllegalArgumentException: if the specified object is not
                     an instance of the class or interface declaring the
                     underlying field (or a subclass or implementor
                     thereof), or if the field value cannot be
                     converted to the type `int` by a
                     widening conversion.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.get
        """
        ...


    def getLong(self, obj: "Object") -> int:
        """
        Gets the value of a static or instance field of type
        `long` or of another primitive type convertible to
        type `long` via a widening conversion.

        Arguments
        - obj: the object to extract the `long` value
        from

        Returns
        - the value of the field converted to type `long`

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is inaccessible.
        - IllegalArgumentException: if the specified object is not
                     an instance of the class or interface declaring the
                     underlying field (or a subclass or implementor
                     thereof), or if the field value cannot be
                     converted to the type `long` by a
                     widening conversion.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.get
        """
        ...


    def getFloat(self, obj: "Object") -> float:
        """
        Gets the value of a static or instance field of type
        `float` or of another primitive type convertible to
        type `float` via a widening conversion.

        Arguments
        - obj: the object to extract the `float` value
        from

        Returns
        - the value of the field converted to type `float`

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is inaccessible.
        - IllegalArgumentException: if the specified object is not
                     an instance of the class or interface declaring the
                     underlying field (or a subclass or implementor
                     thereof), or if the field value cannot be
                     converted to the type `float` by a
                     widening conversion.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.get
        """
        ...


    def getDouble(self, obj: "Object") -> float:
        """
        Gets the value of a static or instance field of type
        `double` or of another primitive type convertible to
        type `double` via a widening conversion.

        Arguments
        - obj: the object to extract the `double` value
        from

        Returns
        - the value of the field converted to type `double`

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is inaccessible.
        - IllegalArgumentException: if the specified object is not
                     an instance of the class or interface declaring the
                     underlying field (or a subclass or implementor
                     thereof), or if the field value cannot be
                     converted to the type `double` by a
                     widening conversion.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.get
        """
        ...


    def set(self, obj: "Object", value: "Object") -> None:
        """
        Sets the field represented by this `Field` object on the
        specified object argument to the specified new value. The new
        value is automatically unwrapped if the underlying field has a
        primitive type.
        
        The operation proceeds as follows:
        
        If the underlying field is static, the `obj` argument is
        ignored; it may be null.
        
        Otherwise the underlying field is an instance field.  If the
        specified object argument is null, the method throws a
        `NullPointerException`.  If the specified object argument is not
        an instance of the class or interface declaring the underlying
        field, the method throws an `IllegalArgumentException`.
        
        If this `Field` object is enforcing Java language access control, and
        the underlying field is inaccessible, the method throws an
        `IllegalAccessException`.
        
        If the underlying field is final, this `Field` object has
        *write* access if and only if the following conditions are met:
        
        - .setAccessible(boolean) setAccessible(True) has succeeded for
            this `Field` object;
        - the field is non-static; and
        - the field's declaring class is not a Class.isHidden()
            hidden class; and
        - the field's declaring class is not a Class.isRecord()
            record class.
        
        If any of the above checks is not met, this method throws an
        `IllegalAccessException`.
        
         Setting a final field in this way
        is meaningful only during deserialization or reconstruction of
        instances of classes with blank final fields, before they are
        made available for access by other parts of a program. Use in
        any other context may have unpredictable effects, including cases
        in which other parts of a program continue to use the original
        value of this field.
        
        If the underlying field is of a primitive type, an unwrapping
        conversion is attempted to convert the new value to a value of
        a primitive type.  If this attempt fails, the method throws an
        `IllegalArgumentException`.
        
        If, after possible unwrapping, the new value cannot be
        converted to the type of the underlying field by an identity or
        widening conversion, the method throws an
        `IllegalArgumentException`.
        
        If the underlying field is static, the class that declared the
        field is initialized if it has not already been initialized.
        
        The field is set to the possibly unwrapped and widened new value.
        
        If the field is hidden in the type of `obj`,
        the field's value is set according to the preceding rules.

        Arguments
        - obj: the object whose field should be modified
        - value: the new value for the field of `obj`
        being modified

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is inaccessible or final;
                     or if this `Field` object has no write access.
        - IllegalArgumentException: if the specified object is not an
                     instance of the class or interface declaring the underlying
                     field (or a subclass or implementor thereof),
                     or if an unwrapping conversion fails.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.
        """
        ...


    def setBoolean(self, obj: "Object", z: bool) -> None:
        """
        Sets the value of a field as a `boolean` on the specified object.
        This method is equivalent to
        `set(obj, zObj)`,
        where `zObj` is a `Boolean` object and
        `zObj.booleanValue() == z`.

        Arguments
        - obj: the object whose field should be modified
        - z: the new value for the field of `obj`
        being modified

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is either inaccessible or final;
                     or if this `Field` object has no write access.
        - IllegalArgumentException: if the specified object is not an
                     instance of the class or interface declaring the underlying
                     field (or a subclass or implementor thereof),
                     or if an unwrapping conversion fails.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.set
        """
        ...


    def setByte(self, obj: "Object", b: int) -> None:
        """
        Sets the value of a field as a `byte` on the specified object.
        This method is equivalent to
        `set(obj, bObj)`,
        where `bObj` is a `Byte` object and
        `bObj.byteValue() == b`.

        Arguments
        - obj: the object whose field should be modified
        - b: the new value for the field of `obj`
        being modified

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is either inaccessible or final;
                     or if this `Field` object has no write access.
        - IllegalArgumentException: if the specified object is not an
                     instance of the class or interface declaring the underlying
                     field (or a subclass or implementor thereof),
                     or if an unwrapping conversion fails.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.set
        """
        ...


    def setChar(self, obj: "Object", c: str) -> None:
        """
        Sets the value of a field as a `char` on the specified object.
        This method is equivalent to
        `set(obj, cObj)`,
        where `cObj` is a `Character` object and
        `cObj.charValue() == c`.

        Arguments
        - obj: the object whose field should be modified
        - c: the new value for the field of `obj`
        being modified

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is either inaccessible or final;
                     or if this `Field` object has no write access.
        - IllegalArgumentException: if the specified object is not an
                     instance of the class or interface declaring the underlying
                     field (or a subclass or implementor thereof),
                     or if an unwrapping conversion fails.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.set
        """
        ...


    def setShort(self, obj: "Object", s: int) -> None:
        """
        Sets the value of a field as a `short` on the specified object.
        This method is equivalent to
        `set(obj, sObj)`,
        where `sObj` is a `Short` object and
        `sObj.shortValue() == s`.

        Arguments
        - obj: the object whose field should be modified
        - s: the new value for the field of `obj`
        being modified

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is either inaccessible or final;
                     or if this `Field` object has no write access.
        - IllegalArgumentException: if the specified object is not an
                     instance of the class or interface declaring the underlying
                     field (or a subclass or implementor thereof),
                     or if an unwrapping conversion fails.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.set
        """
        ...


    def setInt(self, obj: "Object", i: int) -> None:
        """
        Sets the value of a field as an `int` on the specified object.
        This method is equivalent to
        `set(obj, iObj)`,
        where `iObj` is an `Integer` object and
        `iObj.intValue() == i`.

        Arguments
        - obj: the object whose field should be modified
        - i: the new value for the field of `obj`
        being modified

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is either inaccessible or final;
                     or if this `Field` object has no write access.
        - IllegalArgumentException: if the specified object is not an
                     instance of the class or interface declaring the underlying
                     field (or a subclass or implementor thereof),
                     or if an unwrapping conversion fails.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.set
        """
        ...


    def setLong(self, obj: "Object", l: int) -> None:
        """
        Sets the value of a field as a `long` on the specified object.
        This method is equivalent to
        `set(obj, lObj)`,
        where `lObj` is a `Long` object and
        `lObj.longValue() == l`.

        Arguments
        - obj: the object whose field should be modified
        - l: the new value for the field of `obj`
        being modified

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is either inaccessible or final;
                     or if this `Field` object has no write access.
        - IllegalArgumentException: if the specified object is not an
                     instance of the class or interface declaring the underlying
                     field (or a subclass or implementor thereof),
                     or if an unwrapping conversion fails.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.set
        """
        ...


    def setFloat(self, obj: "Object", f: float) -> None:
        """
        Sets the value of a field as a `float` on the specified object.
        This method is equivalent to
        `set(obj, fObj)`,
        where `fObj` is a `Float` object and
        `fObj.floatValue() == f`.

        Arguments
        - obj: the object whose field should be modified
        - f: the new value for the field of `obj`
        being modified

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is either inaccessible or final;
                     or if this `Field` object has no write access.
        - IllegalArgumentException: if the specified object is not an
                     instance of the class or interface declaring the underlying
                     field (or a subclass or implementor thereof),
                     or if an unwrapping conversion fails.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.set
        """
        ...


    def setDouble(self, obj: "Object", d: float) -> None:
        """
        Sets the value of a field as a `double` on the specified object.
        This method is equivalent to
        `set(obj, dObj)`,
        where `dObj` is a `Double` object and
        `dObj.doubleValue() == d`.

        Arguments
        - obj: the object whose field should be modified
        - d: the new value for the field of `obj`
        being modified

        Raises
        - IllegalAccessException: if this `Field` object
                     is enforcing Java language access control and the underlying
                     field is either inaccessible or final;
                     or if this `Field` object has no write access.
        - IllegalArgumentException: if the specified object is not an
                     instance of the class or interface declaring the underlying
                     field (or a subclass or implementor thereof),
                     or if an unwrapping conversion fails.
        - NullPointerException: if the specified object is null
                     and the field is an instance field.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.

        See
        - Field.set
        """
        ...


    def getAnnotation(self, annotationClass: type["T"]) -> "T":
        """
        Raises
        - NullPointerException: 

        Since
        - 1.5
        """
        ...


    def getAnnotationsByType(self, annotationClass: type["T"]) -> list["T"]:
        """
        Raises
        - NullPointerException: 

        Since
        - 1.8
        """
        ...


    def getDeclaredAnnotations(self) -> list["Annotation"]:
        """

        """
        ...


    def getAnnotatedType(self) -> "AnnotatedType":
        """
        Returns an AnnotatedType object that represents the use of a type to specify
        the declared type of the field represented by this Field.

        Returns
        - an object representing the declared type of the field
        represented by this Field

        Since
        - 1.8
        """
        ...



"""
Python module generated from Java source file com.google.common.math.ToDoubleRounder

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.math import *
from java.math import RoundingMode
from typing import Any, Callable, Iterable, Tuple


class ToDoubleRounder:
    """
    Helper type to implement rounding `X` to a representable `double` value according to
    a RoundingMode.
    """





"""
Python module generated from Java source file org.bukkit.block.data.Attachable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import *
from typing import Any, Callable, Iterable, Tuple


class Attachable(BlockData):
    """
    'attached' denotes whether a tripwire hook or string forms a complete
    tripwire circuit and is ready to trigger.
    
    Updating the property on a tripwire hook will change the texture to indicate
    a connected string, but will not have any effect when used on the tripwire
    string itself. It may however still be used to check whether the string forms
    a circuit.
    """

    def isAttached(self) -> bool:
        """
        Gets the value of the 'attached' property.

        Returns
        - the 'attached' value
        """
        ...


    def setAttached(self, attached: bool) -> None:
        """
        Sets the value of the 'attached' property.

        Arguments
        - attached: the new 'attached' value
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.nodes.ScalarNode

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml import DumperOptions
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.nodes import *
from typing import Any, Callable, Iterable, Tuple


class ScalarNode(Node):
    """
    Represents a scalar node.
    
    Scalar nodes form the leaves in the node graph.
    """

    def __init__(self, tag: "Tag", value: str, startMark: "Mark", endMark: "Mark", style: "DumperOptions.ScalarStyle"):
        ...


    def __init__(self, tag: "Tag", resolved: bool, value: str, startMark: "Mark", endMark: "Mark", style: "DumperOptions.ScalarStyle"):
        ...


    def getScalarStyle(self) -> "DumperOptions.ScalarStyle":
        """
        Get scalar style of this node.

        Returns
        - style of this scalar node

        See
        - <a href="http://yaml.org/spec/1.1/.id903915">Chapter 9. Scalar Styles</a>
        """
        ...


    def getNodeId(self) -> "NodeId":
        ...


    def getValue(self) -> str:
        """
        Value of this scalar.

        Returns
        - Scalar's value.
        """
        ...


    def toString(self) -> str:
        ...


    def isPlain(self) -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.ArrowBodyCountChangeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from org.bukkit.entity import LivingEntity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class ArrowBodyCountChangeEvent(EntityEvent, Cancellable):
    """
    Called when an arrow enters or exists an entity's body.
    """

    def __init__(self, entity: "LivingEntity", oldAmount: int, newAmount: int, isReset: bool):
        ...


    def isReset(self) -> bool:
        """
        Whether the event was called because the entity was reset.

        Returns
        - was reset
        """
        ...


    def getOldAmount(self) -> int:
        """
        Gets the old amount of arrows in the entity's body.

        Returns
        - amount of arrows
        """
        ...


    def getNewAmount(self) -> int:
        """
        Get the new amount of arrows in the entity's body.

        Returns
        - amount of arrows
        """
        ...


    def setNewAmount(self, newAmount: int) -> None:
        """
        Sets the final amount of arrows in the entity's body.

        Arguments
        - newAmount: amount of arrows
        """
        ...


    def getEntity(self) -> "LivingEntity":
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.io.LittleEndianDataInputStream

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import Preconditions
from com.google.common.io import *
from com.google.common.primitives import Ints
from com.google.common.primitives import Longs
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotCall
from java.io import DataInput
from java.io import DataInputStream
from java.io import EOFException
from java.io import FilterInputStream
from java.io import IOException
from java.io import InputStream
from typing import Any, Callable, Iterable, Tuple


class LittleEndianDataInputStream(FilterInputStream, DataInput):
    """
    An implementation of DataInput that uses little-endian byte ordering for reading `short`, `int`, `float`, `double`, and `long` values.
    
    **Note:** This class intentionally violates the specification of its supertype `DataInput`, which explicitly requires big-endian byte order.

    Author(s)
    - Keith Bottner

    Since
    - 8.0
    """

    def __init__(self, in: "InputStream"):
        """
        Creates a `LittleEndianDataInputStream` that wraps the given stream.

        Arguments
        - in: the stream to delegate to
        """
        ...


    def readLine(self) -> str:
        """
        This method will throw an UnsupportedOperationException.
        """
        ...


    def readFully(self, b: list[int]) -> None:
        ...


    def readFully(self, b: list[int], off: int, len: int) -> None:
        ...


    def skipBytes(self, n: int) -> int:
        ...


    def readUnsignedByte(self) -> int:
        ...


    def readUnsignedShort(self) -> int:
        """
        Reads an unsigned `short` as specified by DataInputStream.readUnsignedShort(),
        except using little-endian byte order.

        Returns
        - the next two bytes of the input stream, interpreted as an unsigned 16-bit integer in
            little-endian byte order

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def readInt(self) -> int:
        """
        Reads an integer as specified by DataInputStream.readInt(), except using little-endian
        byte order.

        Returns
        - the next four bytes of the input stream, interpreted as an `int` in little-endian
            byte order

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def readLong(self) -> int:
        """
        Reads a `long` as specified by DataInputStream.readLong(), except using
        little-endian byte order.

        Returns
        - the next eight bytes of the input stream, interpreted as a `long` in
            little-endian byte order

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def readFloat(self) -> float:
        """
        Reads a `float` as specified by DataInputStream.readFloat(), except using
        little-endian byte order.

        Returns
        - the next four bytes of the input stream, interpreted as a `float` in
            little-endian byte order

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def readDouble(self) -> float:
        """
        Reads a `double` as specified by DataInputStream.readDouble(), except using
        little-endian byte order.

        Returns
        - the next eight bytes of the input stream, interpreted as a `double` in
            little-endian byte order

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def readUTF(self) -> str:
        ...


    def readShort(self) -> int:
        """
        Reads a `short` as specified by DataInputStream.readShort(), except using
        little-endian byte order.

        Returns
        - the next two bytes of the input stream, interpreted as a `short` in little-endian
            byte order.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def readChar(self) -> str:
        """
        Reads a char as specified by DataInputStream.readChar(), except using little-endian
        byte order.

        Returns
        - the next two bytes of the input stream, interpreted as a `char` in little-endian
            byte order

        Raises
        - IOException: if an I/O error occurs
        """
        ...


    def readByte(self) -> int:
        ...


    def readBoolean(self) -> bool:
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.reader.StreamReader

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from java.io import Reader
from java.io import StringReader
from java.util import Arrays
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.reader import *
from org.yaml.snakeyaml.scanner import Constant
from typing import Any, Callable, Iterable, Tuple


class StreamReader:
    """
    Reader: checks if code points are in allowed range. Returns '\0' when end of data has been
    reached.
    """

    def __init__(self, stream: str):
        ...


    def __init__(self, reader: "Reader"):
        ...


    @staticmethod
    def isPrintable(data: str) -> bool:
        ...


    @staticmethod
    def isPrintable(c: int) -> bool:
        ...


    def getMark(self) -> "Mark":
        ...


    def forward(self) -> None:
        ...


    def forward(self, length: int) -> None:
        """
        read the next length characters and move the pointer. if the last character is high surrogate
        one more character will be read

        Arguments
        - length: amount of characters to move forward
        """
        ...


    def peek(self) -> int:
        ...


    def peek(self, index: int) -> int:
        """
        Peek the next index-th code point

        Arguments
        - index: to peek

        Returns
        - the next index-th code point
        """
        ...


    def prefix(self, length: int) -> str:
        """
        peek the next length code points

        Arguments
        - length: amount of the characters to peek

        Returns
        - the next length code points
        """
        ...


    def prefixForward(self, length: int) -> str:
        """
        prefix(length) immediately followed by forward(length)

        Arguments
        - length: amount of characters to get

        Returns
        - the next length code points
        """
        ...


    def getColumn(self) -> int:
        ...


    def getDocumentIndex(self) -> int:
        """
        Get the position of the current char in the current YAML document

        Returns
        - index of the current position from the beginning of the current document
        """
        ...


    def resetDocumentIndex(self) -> None:
        """
        Reset the position to start (at the start of a new document in the stream)
        """
        ...


    def getIndex(self) -> int:
        """
        Returns
        - current position as number (in characters) from the beginning of the stream
        """
        ...


    def getLine(self) -> int:
        ...



"""
Python module generated from Java source file org.bukkit.plugin.PluginManager

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import File
from org.bukkit.event import Event
from org.bukkit.event import EventPriority
from org.bukkit.event import Listener
from org.bukkit.permissions import Permissible
from org.bukkit.permissions import Permission
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class PluginManager:
    """
    Handles all plugin management from the Server
    """

    def registerInterface(self, loader: type["PluginLoader"]) -> None:
        """
        Registers the specified plugin loader

        Arguments
        - loader: Class name of the PluginLoader to register

        Raises
        - IllegalArgumentException: Thrown when the given Class is not a
            valid PluginLoader
        """
        ...


    def getPlugin(self, name: str) -> "Plugin":
        """
        Checks if the given plugin is loaded and returns it when applicable
        
        Please note that the name of the plugin is case-sensitive

        Arguments
        - name: Name of the plugin to check

        Returns
        - Plugin if it exists, otherwise null
        """
        ...


    def getPlugins(self) -> list["Plugin"]:
        """
        Gets a list of all currently loaded plugins

        Returns
        - Array of Plugins
        """
        ...


    def isPluginEnabled(self, name: str) -> bool:
        """
        Checks if the given plugin is enabled or not
        
        Please note that the name of the plugin is case-sensitive.

        Arguments
        - name: Name of the plugin to check

        Returns
        - True if the plugin is enabled, otherwise False
        """
        ...


    def isPluginEnabled(self, plugin: "Plugin") -> bool:
        """
        Checks if the given plugin is enabled or not

        Arguments
        - plugin: Plugin to check

        Returns
        - True if the plugin is enabled, otherwise False
        """
        ...


    def loadPlugin(self, file: "File") -> "Plugin":
        """
        Loads the plugin in the specified file
        
        File must be valid according to the current enabled Plugin interfaces

        Arguments
        - file: File containing the plugin to load

        Returns
        - The Plugin loaded, or null if it was invalid

        Raises
        - InvalidPluginException: Thrown when the specified file is not a
            valid plugin
        - InvalidDescriptionException: Thrown when the specified file
            contains an invalid description
        - UnknownDependencyException: If a required dependency could not
            be resolved
        """
        ...


    def loadPlugins(self, directory: "File") -> list["Plugin"]:
        """
        Loads the plugins contained within the specified directory

        Arguments
        - directory: Directory to check for plugins

        Returns
        - A list of all plugins loaded
        """
        ...


    def loadPlugins(self, files: list["File"]) -> list["Plugin"]:
        """
        Loads the plugins in the list of the files

        Arguments
        - files: List of files containing plugins to load

        Returns
        - A list of all plugins loaded
        """
        ...


    def disablePlugins(self) -> None:
        """
        Disables all the loaded plugins
        """
        ...


    def clearPlugins(self) -> None:
        """
        Disables and removes all plugins
        """
        ...


    def callEvent(self, event: "Event") -> None:
        """
        Calls an event with the given details

        Arguments
        - event: Event details

        Raises
        - IllegalStateException: Thrown when an asynchronous event is
            fired from synchronous code.
            
            *Note: This is best-effort basis, and should not be used to test
            synchronized state. This is an indicator for flawed flow logic.*
        """
        ...


    def registerEvents(self, listener: "Listener", plugin: "Plugin") -> None:
        """
        Registers all the events in the given listener class

        Arguments
        - listener: Listener to register
        - plugin: Plugin to register
        """
        ...


    def registerEvent(self, event: type["Event"], listener: "Listener", priority: "EventPriority", executor: "EventExecutor", plugin: "Plugin") -> None:
        """
        Registers the specified executor to the given event class

        Arguments
        - event: Event type to register
        - listener: Listener to register
        - priority: Priority to register this event at
        - executor: EventExecutor to register
        - plugin: Plugin to register
        """
        ...


    def registerEvent(self, event: type["Event"], listener: "Listener", priority: "EventPriority", executor: "EventExecutor", plugin: "Plugin", ignoreCancelled: bool) -> None:
        """
        Registers the specified executor to the given event class

        Arguments
        - event: Event type to register
        - listener: Listener to register
        - priority: Priority to register this event at
        - executor: EventExecutor to register
        - plugin: Plugin to register
        - ignoreCancelled: Whether to pass cancelled events or not
        """
        ...


    def enablePlugin(self, plugin: "Plugin") -> None:
        """
        Enables the specified plugin
        
        Attempting to enable a plugin that is already enabled will have no
        effect

        Arguments
        - plugin: Plugin to enable
        """
        ...


    def disablePlugin(self, plugin: "Plugin") -> None:
        """
        Disables the specified plugin
        
        Attempting to disable a plugin that is not enabled will have no effect

        Arguments
        - plugin: Plugin to disable
        """
        ...


    def getPermission(self, name: str) -> "Permission":
        """
        Gets a Permission from its fully qualified name

        Arguments
        - name: Name of the permission

        Returns
        - Permission, or null if none
        """
        ...


    def addPermission(self, perm: "Permission") -> None:
        """
        Adds a Permission to this plugin manager.
        
        If a permission is already defined with the given name of the new
        permission, an exception will be thrown.

        Arguments
        - perm: Permission to add

        Raises
        - IllegalArgumentException: Thrown when a permission with the same
            name already exists
        """
        ...


    def removePermission(self, perm: "Permission") -> None:
        """
        Removes a Permission registration from this plugin manager.
        
        If the specified permission does not exist in this plugin manager,
        nothing will happen.
        
        Removing a permission registration will **not** remove the
        permission from any Permissibles that have it.

        Arguments
        - perm: Permission to remove
        """
        ...


    def removePermission(self, name: str) -> None:
        """
        Removes a Permission registration from this plugin manager.
        
        If the specified permission does not exist in this plugin manager,
        nothing will happen.
        
        Removing a permission registration will **not** remove the
        permission from any Permissibles that have it.

        Arguments
        - name: Permission to remove
        """
        ...


    def getDefaultPermissions(self, op: bool) -> set["Permission"]:
        """
        Gets the default permissions for the given op status

        Arguments
        - op: Which set of default permissions to get

        Returns
        - The default permissions
        """
        ...


    def recalculatePermissionDefaults(self, perm: "Permission") -> None:
        """
        Recalculates the defaults for the given Permission.
        
        This will have no effect if the specified permission is not registered
        here.

        Arguments
        - perm: Permission to recalculate
        """
        ...


    def subscribeToPermission(self, permission: str, permissible: "Permissible") -> None:
        """
        Subscribes the given Permissible for information about the requested
        Permission, by name.
        
        If the specified Permission changes in any form, the Permissible will
        be asked to recalculate.

        Arguments
        - permission: Permission to subscribe to
        - permissible: Permissible subscribing
        """
        ...


    def unsubscribeFromPermission(self, permission: str, permissible: "Permissible") -> None:
        """
        Unsubscribes the given Permissible for information about the requested
        Permission, by name.

        Arguments
        - permission: Permission to unsubscribe from
        - permissible: Permissible subscribing
        """
        ...


    def getPermissionSubscriptions(self, permission: str) -> set["Permissible"]:
        """
        Gets a set containing all subscribed Permissibles to the given
        permission, by name

        Arguments
        - permission: Permission to query for

        Returns
        - Set containing all subscribed permissions
        """
        ...


    def subscribeToDefaultPerms(self, op: bool, permissible: "Permissible") -> None:
        """
        Subscribes to the given Default permissions by operator status
        
        If the specified defaults change in any form, the Permissible will be
        asked to recalculate.

        Arguments
        - op: Default list to subscribe to
        - permissible: Permissible subscribing
        """
        ...


    def unsubscribeFromDefaultPerms(self, op: bool, permissible: "Permissible") -> None:
        """
        Unsubscribes from the given Default permissions by operator status

        Arguments
        - op: Default list to unsubscribe from
        - permissible: Permissible subscribing
        """
        ...


    def getDefaultPermSubscriptions(self, op: bool) -> set["Permissible"]:
        """
        Gets a set containing all subscribed Permissibles to the given
        default list, by op status

        Arguments
        - op: Default list to query for

        Returns
        - Set containing all subscribed permissions
        """
        ...


    def getPermissions(self) -> set["Permission"]:
        """
        Gets a set of all registered permissions.
        
        This set is a copy and will not be modified live.

        Returns
        - Set containing all current registered permissions
        """
        ...


    def useTimings(self) -> bool:
        """
        Returns whether or not timing code should be used for event calls

        Returns
        - True if event timings are to be used
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.MapMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Color
from org.bukkit import UndefinedNullability
from org.bukkit.inventory.meta import *
from org.bukkit.map import MapView
from typing import Any, Callable, Iterable, Tuple


class MapMeta(ItemMeta):
    """
    Represents a map that can be scalable.
    """

    def hasMapId(self) -> bool:
        """
        Checks for existence of a map ID number.

        Returns
        - True if this has a map ID number.

        See
        - .hasMapView()

        Deprecated
        - These methods are poor API: They rely on the caller to pass
        in an only an integer property, and have poorly defined implementation
        behavior if that integer is not a valid map (the current implementation
        for example will generate a new map with a different ID). The xxxMapView
        family of methods should be used instead.
        """
        ...


    def getMapId(self) -> int:
        """
        Gets the map ID that is set. This is used to determine what map is
        displayed.
        
        Plugins should check that hasMapId() returns `True` before
        calling this method.

        Returns
        - the map ID that is set

        See
        - .getMapView()

        Deprecated
        - These methods are poor API: They rely on the caller to pass
        in an only an integer property, and have poorly defined implementation
        behavior if that integer is not a valid map (the current implementation
        for example will generate a new map with a different ID). The xxxMapView
        family of methods should be used instead.
        """
        ...


    def setMapId(self, id: int) -> None:
        """
        Sets the map ID. This is used to determine what map is displayed.

        Arguments
        - id: the map id to set

        See
        - .setMapView(org.bukkit.map.MapView)

        Deprecated
        - These methods are poor API: They rely on the caller to pass
        in an only an integer property, and have poorly defined implementation
        behavior if that integer is not a valid map (the current implementation
        for example will generate a new map with a different ID). The xxxMapView
        family of methods should be used instead.
        """
        ...


    def hasMapView(self) -> bool:
        """
        Checks for existence of an associated map.

        Returns
        - True if this item has an associated map
        """
        ...


    def getMapView(self) -> "MapView":
        """
        Gets the map view that is associated with this map item.
        
        
        Plugins should check that hasMapView() returns `True` before
        calling this method.

        Returns
        - the map view, or null if the item hasMapView(), but this map does
        not exist on the server
        """
        ...


    def setMapView(self, map: "MapView") -> None:
        """
        Sets the associated map. This is used to determine what map is displayed.
        
        
        The implementation **may** allow null to clear the associated map, but
        this is not required and is liable to generate a new (undefined) map when
        the item is first used.

        Arguments
        - map: the map to set
        """
        ...


    def isScaling(self) -> bool:
        """
        Checks to see if this map is scaling.

        Returns
        - True if this map is scaling
        """
        ...


    def setScaling(self, value: bool) -> None:
        """
        Sets if this map is scaling or not.

        Arguments
        - value: True to scale
        """
        ...


    def hasLocationName(self) -> bool:
        """
        Checks for existence of a location name.

        Returns
        - True if this has a location name

        Deprecated
        - This method does not have the expected effect and is
        actually an alias for ItemMeta.hasLocalizedName().
        """
        ...


    def getLocationName(self) -> str:
        """
        Gets the location name that is set.
        
        Plugins should check that hasLocationName() returns `True`
        before calling this method.

        Returns
        - the location name that is set

        Deprecated
        - This method does not have the expected effect and is
        actually an alias for ItemMeta.getLocalizedName().
        """
        ...


    def setLocationName(self, name: str) -> None:
        """
        Sets the location name.

        Arguments
        - name: the name to set

        Deprecated
        - This method does not have the expected effect and is
        actually an alias for ItemMeta.setLocalizedName(String).
        """
        ...


    def hasColor(self) -> bool:
        """
        Checks for existence of a map color.

        Returns
        - True if this has a custom map color
        """
        ...


    def getColor(self) -> "Color":
        """
        Gets the map color that is set. A custom map color will alter the display
        of the map in an inventory slot.
        
        Plugins should check that hasColor() returns `True` before
        calling this method.

        Returns
        - the map color that is set
        """
        ...


    def setColor(self, color: "Color") -> None:
        """
        Sets the map color. A custom map color will alter the display of the map
        in an inventory slot.

        Arguments
        - color: the color to set
        """
        ...


    def clone(self) -> "MapMeta":
        ...



"""
Python module generated from Java source file com.google.common.collect.TreeMultiset

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import MoreObjects
from com.google.common.collect import *
from com.google.common.primitives import Ints
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.io import IOException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.io import Serializable
from java.util import Comparator
from java.util import ConcurrentModificationException
from java.util import Iterator
from java.util import NoSuchElementException
from java.util.function import ObjIntConsumer
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class TreeMultiset(AbstractSortedMultiset, Serializable):
    """
    A multiset which maintains the ordering of its elements, according to either their natural order
    or an explicit Comparator. In all cases, this implementation uses Comparable.compareTo or Comparator.compare instead of Object.equals to determine
    equivalence of instances.
    
    **Warning:** The comparison must be *consistent with equals* as explained by the
    Comparable class specification. Otherwise, the resulting multiset will violate the java.util.Collection contract, which is specified in terms of Object.equals.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#multiset">`Multiset`</a>.

    Author(s)
    - Jared Levy

    Since
    - 2.0
    """

    @staticmethod
    def create() -> "TreeMultiset"["E"]:
        """
        Creates a new, empty multiset, sorted according to the elements' natural order. All elements
        inserted into the multiset must implement the `Comparable` interface. Furthermore, all
        such elements must be *mutually comparable*: `e1.compareTo(e2)` must not throw a
        `ClassCastException` for any elements `e1` and `e2` in the multiset. If the
        user attempts to add an element to the multiset that violates this constraint (for example, the
        user attempts to add a string element to a set whose elements are integers), the `add(Object)` call will throw a `ClassCastException`.
        
        The type specification is `<E extends Comparable>`, instead of the more specific
        `<E extends Comparable<? super E>>`, to support classes defined without generics.
        """
        ...


    @staticmethod
    def create(comparator: "Comparator"["E"]) -> "TreeMultiset"["E"]:
        """
        Creates a new, empty multiset, sorted according to the specified comparator. All elements
        inserted into the multiset must be *mutually comparable* by the specified comparator:
        `comparator.compare(e1, e2)` must not throw a `ClassCastException` for any elements
        `e1` and `e2` in the multiset. If the user attempts to add an element to the
        multiset that violates this constraint, the `add(Object)` call will throw a `ClassCastException`.

        Arguments
        - comparator: the comparator that will be used to sort this multiset. A null value
            indicates that the elements' *natural ordering* should be used.
        """
        ...


    @staticmethod
    def create(elements: Iterable["E"]) -> "TreeMultiset"["E"]:
        """
        Creates an empty multiset containing the given initial elements, sorted according to the
        elements' natural order.
        
        This implementation is highly efficient when `elements` is itself a Multiset.
        
        The type specification is `<E extends Comparable>`, instead of the more specific
        `<E extends Comparable<? super E>>`, to support classes defined without generics.
        """
        ...


    def size(self) -> int:
        ...


    def count(self, element: "Object") -> int:
        ...


    def add(self, element: "E", occurrences: int) -> int:
        ...


    def remove(self, element: "Object", occurrences: int) -> int:
        ...


    def setCount(self, element: "E", count: int) -> int:
        ...


    def setCount(self, element: "E", oldCount: int, newCount: int) -> bool:
        ...


    def clear(self) -> None:
        ...


    def forEachEntry(self, action: "ObjIntConsumer"["E"]) -> None:
        ...


    def iterator(self) -> Iterator["E"]:
        ...


    def headMultiset(self, upperBound: "E", boundType: "BoundType") -> "SortedMultiset"["E"]:
        ...


    def tailMultiset(self, lowerBound: "E", boundType: "BoundType") -> "SortedMultiset"["E"]:
        ...



"""
Python module generated from Java source file com.google.common.eventbus.Subscribe

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.eventbus import *
from typing import Any, Callable, Iterable, Tuple


class Subscribe:
    """
    Marks a method as an event subscriber.
    
    The type of event will be indicated by the method's first (and only) parameter, which cannot
    be primitive. If this annotation is applied to methods with zero parameters, or more than one
    parameter, the object containing the method will not be able to register for event delivery from
    the EventBus.
    
    Unless also annotated with @AllowConcurrentEvents, event subscriber methods will be
    invoked serially by each event bus that they are registered with.

    Author(s)
    - Cliff Biffle

    Since
    - 10.0
    """





"""
Python module generated from Java source file org.bukkit.event.block.BlockExplodeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import ExplosionResult
from org.bukkit.block import Block
from org.bukkit.block import BlockState
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BlockExplodeEvent(BlockEvent, Cancellable):
    """
    Called when a block explodes.
    
    Note that due to the nature of explosions, .getBlock() will always be
    an air block. .getExplodedBlockState() should be used to get
    information about the block state that exploded.
    """

    def __init__(self, what: "Block", blockState: "BlockState", blocks: list["Block"], yield: float, result: "ExplosionResult"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getExplosionResult(self) -> "ExplosionResult":
        """
        Returns the result of the explosion if it is not cancelled.

        Returns
        - the result of the explosion
        """
        ...


    def getExplodedBlockState(self) -> "BlockState":
        """
        Returns the captured BlockState of the block that exploded.

        Returns
        - the block state
        """
        ...


    def blockList(self) -> list["Block"]:
        """
        Returns the list of blocks that would have been removed or were removed
        from the explosion event.

        Returns
        - All blown-up blocks
        """
        ...


    def getYield(self) -> float:
        """
        Returns the percentage of blocks to drop from this explosion

        Returns
        - The yield.
        """
        ...


    def setYield(self, yield: float) -> None:
        """
        Sets the percentage of blocks to drop from this explosion

        Arguments
        - yield: The new yield percentage
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.emitter.ScalarAnalysis

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.emitter import *
from typing import Any, Callable, Iterable, Tuple


class ScalarAnalysis:
    """
    Accumulate information to choose the scalar style
    """

    def __init__(self, scalar: str, empty: bool, multiline: bool, allowFlowPlain: bool, allowBlockPlain: bool, allowSingleQuoted: bool, allowBlock: bool):
        ...


    def getScalar(self) -> str:
        ...


    def isEmpty(self) -> bool:
        ...


    def isMultiline(self) -> bool:
        ...


    def isAllowFlowPlain(self) -> bool:
        ...


    def isAllowBlockPlain(self) -> bool:
        ...


    def isAllowSingleQuoted(self) -> bool:
        ...


    def isAllowBlock(self) -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.block.Dispenser

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Nameable
from org.bukkit.block import *
from org.bukkit.loot import Lootable
from org.bukkit.projectiles import BlockProjectileSource
from typing import Any, Callable, Iterable, Tuple


class Dispenser(Container, Nameable, Lootable):
    """
    Represents a captured state of a dispenser.
    """

    def getBlockProjectileSource(self) -> "BlockProjectileSource":
        """
        Gets the BlockProjectileSource object for the dispenser.
        
        If the block represented by this state is no longer a dispenser, this
        will return null.

        Returns
        - a BlockProjectileSource if valid, otherwise null

        Raises
        - IllegalStateException: if this block state is not placed
        """
        ...


    def dispense(self) -> bool:
        """
        Attempts to dispense the contents of the dispenser.
        
        If the block represented by this state is no longer a dispenser, this
        will return False.

        Returns
        - True if successful, otherwise False

        Raises
        - IllegalStateException: if this block state is not placed
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.server.RemoteServerCommandEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.command import CommandSender
from org.bukkit.event import HandlerList
from org.bukkit.event.server import *
from typing import Any, Callable, Iterable, Tuple


class RemoteServerCommandEvent(ServerCommandEvent):
    """
    This event is called when a command is received over RCON. See the javadocs
    of ServerCommandEvent for more information.
    """

    def __init__(self, sender: "CommandSender", command: str):
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file java.util.concurrent.atomic.AtomicIntegerArray

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.invoke import MethodHandles
from java.lang.invoke import VarHandle
from java.util.concurrent.atomic import *
from java.util.function import IntBinaryOperator
from java.util.function import IntUnaryOperator
from typing import Any, Callable, Iterable, Tuple


class AtomicIntegerArray(Serializable):
    """
    An `int` array in which elements may be updated atomically.
    See the VarHandle specification for descriptions of the
    properties of atomic accesses.

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def __init__(self, length: int):
        """
        Creates a new AtomicIntegerArray of the given length, with all
        elements initially zero.

        Arguments
        - length: the length of the array
        """
        ...


    def __init__(self, array: list[int]):
        """
        Creates a new AtomicIntegerArray with the same length as, and
        all elements copied from, the given array.

        Arguments
        - array: the array to copy elements from

        Raises
        - NullPointerException: if array is null
        """
        ...


    def length(self) -> int:
        """
        Returns the length of the array.

        Returns
        - the length of the array
        """
        ...


    def get(self, i: int) -> int:
        """
        Returns the current value of the element at index `i`,
        with memory effects as specified by VarHandle.getVolatile.

        Arguments
        - i: the index

        Returns
        - the current value
        """
        ...


    def set(self, i: int, newValue: int) -> None:
        """
        Sets the element at index `i` to `newValue`,
        with memory effects as specified by VarHandle.setVolatile.

        Arguments
        - i: the index
        - newValue: the new value
        """
        ...


    def lazySet(self, i: int, newValue: int) -> None:
        """
        Sets the element at index `i` to `newValue`,
        with memory effects as specified by VarHandle.setRelease.

        Arguments
        - i: the index
        - newValue: the new value

        Since
        - 1.6
        """
        ...


    def getAndSet(self, i: int, newValue: int) -> int:
        """
        Atomically sets the element at index `i` to `newValue` and returns the old value,
        with memory effects as specified by VarHandle.getAndSet.

        Arguments
        - i: the index
        - newValue: the new value

        Returns
        - the previous value
        """
        ...


    def compareAndSet(self, i: int, expectedValue: int, newValue: int) -> bool:
        """
        Atomically sets the element at index `i` to `newValue` if the element's current value `== expectedValue`,
        with memory effects as specified by VarHandle.compareAndSet.

        Arguments
        - i: the index
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - `True` if successful. False return indicates that
        the actual value was not equal to the expected value.
        """
        ...


    def weakCompareAndSet(self, i: int, expectedValue: int, newValue: int) -> bool:
        """
        Possibly atomically sets the element at index `i` to
        `newValue` if the element's current value `== expectedValue`,
        with memory effects as specified by VarHandle.weakCompareAndSetPlain.

        Arguments
        - i: the index
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - `True` if successful

        See
        - .weakCompareAndSetPlain

        Deprecated
        - This method has plain memory effects but the method
        name implies volatile memory effects (see methods such as
        .compareAndExchange and .compareAndSet).  To avoid
        confusion over plain or volatile memory effects it is recommended that
        the method .weakCompareAndSetPlain be used instead.
        """
        ...


    def weakCompareAndSetPlain(self, i: int, expectedValue: int, newValue: int) -> bool:
        """
        Possibly atomically sets the element at index `i` to
        `newValue` if the element's current value `== expectedValue`,
        with memory effects as specified by VarHandle.weakCompareAndSetPlain.

        Arguments
        - i: the index
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - `True` if successful

        Since
        - 9
        """
        ...


    def getAndIncrement(self, i: int) -> int:
        """
        Atomically increments the value of the element at index `i`,
        with memory effects as specified by VarHandle.getAndAdd.
        
        Equivalent to `getAndAdd(i, 1)`.

        Arguments
        - i: the index

        Returns
        - the previous value
        """
        ...


    def getAndDecrement(self, i: int) -> int:
        """
        Atomically decrements the value of the element at index `i`,
        with memory effects as specified by VarHandle.getAndAdd.
        
        Equivalent to `getAndAdd(i, -1)`.

        Arguments
        - i: the index

        Returns
        - the previous value
        """
        ...


    def getAndAdd(self, i: int, delta: int) -> int:
        """
        Atomically adds the given value to the element at index `i`,
        with memory effects as specified by VarHandle.getAndAdd.

        Arguments
        - i: the index
        - delta: the value to add

        Returns
        - the previous value
        """
        ...


    def incrementAndGet(self, i: int) -> int:
        """
        Atomically increments the value of the element at index `i`,
        with memory effects as specified by VarHandle.getAndAdd.
        
        Equivalent to `addAndGet(i, 1)`.

        Arguments
        - i: the index

        Returns
        - the updated value
        """
        ...


    def decrementAndGet(self, i: int) -> int:
        """
        Atomically decrements the value of the element at index `i`,
        with memory effects as specified by VarHandle.getAndAdd.
        
        Equivalent to `addAndGet(i, -1)`.

        Arguments
        - i: the index

        Returns
        - the updated value
        """
        ...


    def addAndGet(self, i: int, delta: int) -> int:
        """
        Atomically adds the given value to the element at index `i`,
        with memory effects as specified by VarHandle.getAndAdd.

        Arguments
        - i: the index
        - delta: the value to add

        Returns
        - the updated value
        """
        ...


    def getAndUpdate(self, i: int, updateFunction: "IntUnaryOperator") -> int:
        """
        Atomically updates (with memory effects as specified by VarHandle.compareAndSet) the element at index `i` with
        the results of applying the given function, returning the
        previous value. The function should be side-effect-free, since
        it may be re-applied when attempted updates fail due to
        contention among threads.

        Arguments
        - i: the index
        - updateFunction: a side-effect-free function

        Returns
        - the previous value

        Since
        - 1.8
        """
        ...


    def updateAndGet(self, i: int, updateFunction: "IntUnaryOperator") -> int:
        """
        Atomically updates (with memory effects as specified by VarHandle.compareAndSet) the element at index `i` with
        the results of applying the given function, returning the
        updated value. The function should be side-effect-free, since it
        may be re-applied when attempted updates fail due to contention
        among threads.

        Arguments
        - i: the index
        - updateFunction: a side-effect-free function

        Returns
        - the updated value

        Since
        - 1.8
        """
        ...


    def getAndAccumulate(self, i: int, x: int, accumulatorFunction: "IntBinaryOperator") -> int:
        """
        Atomically updates (with memory effects as specified by VarHandle.compareAndSet) the element at index `i` with
        the results of applying the given function to the current and
        given values, returning the previous value. The function should
        be side-effect-free, since it may be re-applied when attempted
        updates fail due to contention among threads.  The function is
        applied with the current value of the element at index `i`
        as its first argument, and the given update as the second
        argument.

        Arguments
        - i: the index
        - x: the update value
        - accumulatorFunction: a side-effect-free function of two arguments

        Returns
        - the previous value

        Since
        - 1.8
        """
        ...


    def accumulateAndGet(self, i: int, x: int, accumulatorFunction: "IntBinaryOperator") -> int:
        """
        Atomically updates (with memory effects as specified by VarHandle.compareAndSet) the element at index `i` with
        the results of applying the given function to the current and
        given values, returning the updated value. The function should
        be side-effect-free, since it may be re-applied when attempted
        updates fail due to contention among threads.  The function is
        applied with the current value of the element at index `i`
        as its first argument, and the given update as the second
        argument.

        Arguments
        - i: the index
        - x: the update value
        - accumulatorFunction: a side-effect-free function of two arguments

        Returns
        - the updated value

        Since
        - 1.8
        """
        ...


    def toString(self) -> str:
        """
        Returns the String representation of the current values of array.

        Returns
        - the String representation of the current values of array
        """
        ...


    def getPlain(self, i: int) -> int:
        """
        Returns the current value of the element at index `i`,
        with memory semantics of reading as if the variable was declared
        non-`volatile`.

        Arguments
        - i: the index

        Returns
        - the value

        Since
        - 9
        """
        ...


    def setPlain(self, i: int, newValue: int) -> None:
        """
        Sets the element at index `i` to `newValue`,
        with memory semantics of setting as if the variable was
        declared non-`volatile` and non-`final`.

        Arguments
        - i: the index
        - newValue: the new value

        Since
        - 9
        """
        ...


    def getOpaque(self, i: int) -> int:
        """
        Returns the current value of the element at index `i`,
        with memory effects as specified by VarHandle.getOpaque.

        Arguments
        - i: the index

        Returns
        - the value

        Since
        - 9
        """
        ...


    def setOpaque(self, i: int, newValue: int) -> None:
        """
        Sets the element at index `i` to `newValue`,
        with memory effects as specified by VarHandle.setOpaque.

        Arguments
        - i: the index
        - newValue: the new value

        Since
        - 9
        """
        ...


    def getAcquire(self, i: int) -> int:
        """
        Returns the current value of the element at index `i`,
        with memory effects as specified by VarHandle.getAcquire.

        Arguments
        - i: the index

        Returns
        - the value

        Since
        - 9
        """
        ...


    def setRelease(self, i: int, newValue: int) -> None:
        """
        Sets the element at index `i` to `newValue`,
        with memory effects as specified by VarHandle.setRelease.

        Arguments
        - i: the index
        - newValue: the new value

        Since
        - 9
        """
        ...


    def compareAndExchange(self, i: int, expectedValue: int, newValue: int) -> int:
        """
        Atomically sets the element at index `i` to `newValue`
        if the element's current value, referred to as the *witness
        value*, `== expectedValue`,
        with memory effects as specified by
        VarHandle.compareAndExchange.

        Arguments
        - i: the index
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - the witness value, which will be the same as the
        expected value if successful

        Since
        - 9
        """
        ...


    def compareAndExchangeAcquire(self, i: int, expectedValue: int, newValue: int) -> int:
        """
        Atomically sets the element at index `i` to `newValue`
        if the element's current value, referred to as the *witness
        value*, `== expectedValue`,
        with memory effects as specified by
        VarHandle.compareAndExchangeAcquire.

        Arguments
        - i: the index
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - the witness value, which will be the same as the
        expected value if successful

        Since
        - 9
        """
        ...


    def compareAndExchangeRelease(self, i: int, expectedValue: int, newValue: int) -> int:
        """
        Atomically sets the element at index `i` to `newValue`
        if the element's current value, referred to as the *witness
        value*, `== expectedValue`,
        with memory effects as specified by
        VarHandle.compareAndExchangeRelease.

        Arguments
        - i: the index
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - the witness value, which will be the same as the
        expected value if successful

        Since
        - 9
        """
        ...


    def weakCompareAndSetVolatile(self, i: int, expectedValue: int, newValue: int) -> bool:
        """
        Possibly atomically sets the element at index `i` to
        `newValue` if the element's current value `== expectedValue`,
        with memory effects as specified by
        VarHandle.weakCompareAndSet.

        Arguments
        - i: the index
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - `True` if successful

        Since
        - 9
        """
        ...


    def weakCompareAndSetAcquire(self, i: int, expectedValue: int, newValue: int) -> bool:
        """
        Possibly atomically sets the element at index `i` to
        `newValue` if the element's current value `== expectedValue`,
        with memory effects as specified by
        VarHandle.weakCompareAndSetAcquire.

        Arguments
        - i: the index
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - `True` if successful

        Since
        - 9
        """
        ...


    def weakCompareAndSetRelease(self, i: int, expectedValue: int, newValue: int) -> bool:
        """
        Possibly atomically sets the element at index `i` to
        `newValue` if the element's current value `== expectedValue`,
        with memory effects as specified by
        VarHandle.weakCompareAndSetRelease.

        Arguments
        - i: the index
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - `True` if successful

        Since
        - 9
        """
        ...



"""
Python module generated from Java source file org.bukkit.material.TripwireHook

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class TripwireHook(SimpleAttachableMaterialData, Redstone):
    """
    Represents the tripwire hook

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def __init__(self, dir: "BlockFace"):
        ...


    def isConnected(self) -> bool:
        """
        Test if tripwire is connected

        Returns
        - True if connected, False if not
        """
        ...


    def setConnected(self, connected: bool) -> None:
        """
        Set tripwire connection state

        Arguments
        - connected: - True if connected, False if not
        """
        ...


    def isActivated(self) -> bool:
        """
        Test if hook is currently activated

        Returns
        - True if activated, False if not
        """
        ...


    def setActivated(self, act: bool) -> None:
        """
        Set hook activated state

        Arguments
        - act: - True if activated, False if not
        """
        ...


    def setFacingDirection(self, face: "BlockFace") -> None:
        ...


    def getAttachedFace(self) -> "BlockFace":
        ...


    def isPowered(self) -> bool:
        ...


    def clone(self) -> "TripwireHook":
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.Fluid

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import Lists
from java.util import Locale
from org.bukkit import *
from org.bukkit.registry import RegistryAware
from org.bukkit.util import OldEnum
from typing import Any, Callable, Iterable, Tuple


class Fluid(OldEnum, Keyed, RegistryAware):
    """
    Represents a fluid type.
    """

    EMPTY = getFluid("empty")
    """
    No fluid.
    """
    WATER = getFluid("water")
    """
    Stationary water.
    """
    FLOWING_WATER = getFluid("flowing_water")
    """
    Flowing water.
    """
    LAVA = getFluid("lava")
    """
    Stationary lava.
    """
    FLOWING_LAVA = getFluid("flowing_lava")
    """
    Flowing lava.
    """


    @staticmethod
    def getFluid(key: str) -> "Fluid":
        ...


    def getKey(self) -> "NamespacedKey":
        """
        See
        - .isRegistered()

        Deprecated
        - A key might not always be present, use .getKeyOrThrow() instead.
        """
        ...


    @staticmethod
    def valueOf(name: str) -> "Fluid":
        """
        Arguments
        - name: of the fluid.

        Returns
        - the fluid with the given name.

        Deprecated
        - only for backwards compatibility, use Registry.get(NamespacedKey) instead.
        """
        ...


    @staticmethod
    def values() -> list["Fluid"]:
        """
        Returns
        - an array of all known fluids.

        Deprecated
        - use Registry.iterator().
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Painting

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Art
from org.bukkit.entity import *
from org.bukkit.event.hanging import HangingBreakEvent
from typing import Any, Callable, Iterable, Tuple


class Painting(Hanging):
    """
    Represents a Painting.
    """

    def getArt(self) -> "Art":
        """
        Get the art on this painting

        Returns
        - The art
        """
        ...


    def setArt(self, art: "Art") -> bool:
        """
        Set the art on this painting

        Arguments
        - art: The new art

        Returns
        - False if the new art won't fit at the painting's current
            location
        """
        ...


    def setArt(self, art: "Art", force: bool) -> bool:
        """
        Set the art on this painting

        Arguments
        - art: The new art
        - force: If True, force the new art regardless of whether it fits
            at the current location. Note that forcing it where it can't fit
            normally causes it to drop as an item unless you override this by
            catching the HangingBreakEvent.

        Returns
        - False if force was False and the new art won't fit at the
            painting's current location
        """
        ...



"""
Python module generated from Java source file com.google.common.reflect.AbstractInvocationHandler

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.reflect import *
from java.lang.reflect import InvocationHandler
from java.lang.reflect import Method
from java.lang.reflect import Proxy
from java.util import Arrays
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractInvocationHandler(InvocationHandler):
    """
    Abstract implementation of InvocationHandler that handles Object.equals, Object.hashCode and Object.toString. For example:
    
    ```
    class Unsupported extends AbstractInvocationHandler {
      protected Object handleInvocation(Object proxy, Method method, Object[] args) {
        throw new UnsupportedOperationException();
      }
    }
    
    CharSequence unsupported = Reflection.newProxy(CharSequence.class, new Unsupported());
    ```

    Author(s)
    - Ben Yu

    Since
    - 12.0
    """

    def invoke(self, proxy: "Object", method: "Method", args: list["Object"]) -> "Object":
        """
        
        
        
          - `proxy.hashCode()` delegates to AbstractInvocationHandler.hashCode
          - `proxy.toString()` delegates to AbstractInvocationHandler.toString
          - `proxy.equals(argument)` returns True if:
              
                - `proxy` and `argument` are of the same type
                - and AbstractInvocationHandler.equals returns True for the InvocationHandler of `argument`
              
          - other method calls are dispatched to .handleInvocation.
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        By default delegates to Object.equals so instances are only equal if they are
        identical. `proxy.equals(argument)` returns True if:
        
        
          - `proxy` and `argument` are of the same type
          - and this method returns True for the InvocationHandler of `argument`
        
        
        Subclasses can override this method to provide custom equality.
        """
        ...


    def hashCode(self) -> int:
        """
        By default delegates to Object.hashCode. The dynamic proxies' `hashCode()` will
        delegate to this method. Subclasses can override this method to provide custom equality.
        """
        ...


    def toString(self) -> str:
        """
        By default delegates to Object.toString. The dynamic proxies' `toString()` will
        delegate to this method. Subclasses can override this method to provide custom string
        representation for the proxies.
        """
        ...



"""
Python module generated from Java source file com.google.common.reflect.TypeParameter

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.reflect import *
from java.lang.reflect import Type
from java.lang.reflect import TypeVariable
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class TypeParameter(TypeCapture):
    """
    Captures a free type variable that can be used in TypeToken.where. For example:
    
    ````static <T> TypeToken<List<T>> listOf(Class<T> elementType) {
      return new TypeToken<List<T>>() {`
          .where(new TypeParameter<T>() {}, elementType);
    }
    }```

    Author(s)
    - Ben Yu

    Since
    - 12.0
    """

    def hashCode(self) -> int:
        ...


    def equals(self, o: "Object") -> bool:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.event.inventory.InventoryEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import HumanEntity
from org.bukkit.event import Event
from org.bukkit.event import HandlerList
from org.bukkit.event.inventory import *
from org.bukkit.inventory import Inventory
from org.bukkit.inventory import InventoryView
from typing import Any, Callable, Iterable, Tuple


class InventoryEvent(Event):
    """
    Represents a player related inventory event
    """

    def __init__(self, transaction: "InventoryView"):
        ...


    def getInventory(self) -> "Inventory":
        """
        Gets the primary Inventory involved in this transaction

        Returns
        - The upper inventory.
        """
        ...


    def getViewers(self) -> list["HumanEntity"]:
        """
        Gets the list of players viewing the primary (upper) inventory involved
        in this event

        Returns
        - A list of people viewing.
        """
        ...


    def getView(self) -> "InventoryView":
        """
        Gets the view object itself

        Returns
        - InventoryView
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.escape.ArrayBasedEscaperMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.escape import *
from java.util import Collections
from typing import Any, Callable, Iterable, Tuple


class ArrayBasedEscaperMap:
    """
    An implementation-specific parameter class suitable for initializing ArrayBasedCharEscaper or ArrayBasedUnicodeEscaper instances. This class should be used
    when more than one escaper is created using the same character replacement mapping to allow the
    underlying (implementation specific) data structures to be shared.
    
    The size of the data structure used by ArrayBasedCharEscaper and ArrayBasedUnicodeEscaper is
    proportional to the highest valued character that has a replacement. For example a replacement
    map containing the single character '\u1000' will require approximately 16K of memory.
    As such sharing this data structure between escaper instances is the primary goal of this class.

    Author(s)
    - David Beaumont

    Since
    - 15.0
    """

    @staticmethod
    def create(replacements: dict["Character", str]) -> "ArrayBasedEscaperMap":
        """
        Returns a new ArrayBasedEscaperMap for creating ArrayBasedCharEscaper or
        ArrayBasedUnicodeEscaper instances.

        Arguments
        - replacements: a map of characters to their escaped representations
        """
        ...



from .TranslationRegistry import TranslationRegistry
from .TranslatableComponentSerializer import TranslatableComponentSerializer
from .TextComponentSerializer import TextComponentSerializer
from .SelectorComponentSerializer import SelectorComponentSerializer
from .ScoreComponentSerializer import ScoreComponentSerializer
from .KeybindComponentSerializer import KeybindComponentSerializer
from .ComponentStyleSerializer import ComponentStyleSerializer
from .ComponentSerializer import ComponentSerializer
from .BaseComponentSerializer import BaseComponentSerializer


"""
Python module generated from Java source file org.bukkit.material.WoodenStep

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit import TreeSpecies
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class WoodenStep(Wood):
    """
    Represents the different types of wooden steps.

    See
    - Material.LEGACY_WOOD_STEP

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        """
        Constructs a wooden step.
        """
        ...


    def __init__(self, species: "TreeSpecies"):
        """
        Constructs a wooden step of the given tree species.

        Arguments
        - species: the species of the wooden step
        """
        ...


    def __init__(self, species: "TreeSpecies", inv: bool):
        """
        Constructs a wooden step of the given type and tree species, either
        inverted or not.

        Arguments
        - species: the species of the wooden step
        - inv: True the step is at the top of the block
        """
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def isInverted(self) -> bool:
        """
        Test if step is inverted

        Returns
        - True if inverted (top half), False if normal (bottom half)
        """
        ...


    def setInverted(self, inv: bool) -> None:
        """
        Set step inverted state

        Arguments
        - inv: - True if step is inverted (top half), False if step is normal
        (bottom half)
        """
        ...


    def clone(self) -> "WoodenStep":
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file net.md_5.bungee.api.ChatMessageType

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from net.md_5.bungee.api import *
from typing import Any, Callable, Iterable, Tuple


class ChatMessageType(Enum):
    """
    Represents the position on the screen where a message will appear.
    """

    CHAT = 0
    SYSTEM = 1
    ACTION_BAR = 2



"""
Python module generated from Java source file org.bukkit.block.data.type.ChiseledBookshelf

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Directional
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class ChiseledBookshelf(Directional):
    """
    Interface to the 'slot_0_occupied', 'slow_1_occupied' ... 'slot_5_occupied'
    flags on a bookshelf which indicate which slots are occupied rendered on the
    outside.
    
    Block may have 0, 1... .getMaximumOccupiedSlots()-1 occupied slots.
    """

    def isSlotOccupied(self, slot: int) -> bool:
        """
        Checks if the following slot is occupied.

        Arguments
        - slot: to check

        Returns
        - if slot is occupied
        """
        ...


    def setSlotOccupied(self, slot: int, occupied: bool) -> None:
        """
        Sets whether the following slot is occupied.

        Arguments
        - slot: to set
        - occupied: book
        """
        ...


    def getOccupiedSlots(self) -> set["Integer"]:
        """
        Get the indexes of all the occupied slots present on this block.

        Returns
        - set of all occupied slots
        """
        ...


    def getMaximumOccupiedSlots(self) -> int:
        """
        Get the maximum amount of slots on this block.

        Returns
        - maximum occupied slots count
        """
        ...



"""
Python module generated from Java source file java.util.function.BiPredicate

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Objects
from java.util.function import *
from typing import Any, Callable, Iterable, Tuple


class BiPredicate:
    """
    Represents a predicate (boolean-valued function) of two arguments.  This is
    the two-arity specialization of Predicate.
    
    This is a <a href="package-summary.html">functional interface</a>
    whose functional method is .test(Object, Object).
    
    Type `<T>`: the type of the first argument to the predicate
    
    Type `<U>`: the type of the second argument the predicate

    See
    - Predicate

    Since
    - 1.8
    """

    def test(self, t: "T", u: "U") -> bool:
        """
        Evaluates this predicate on the given arguments.

        Arguments
        - t: the first input argument
        - u: the second input argument

        Returns
        - `True` if the input arguments match the predicate,
        otherwise `False`
        """
        ...


    def and(self, other: "BiPredicate"["T", "U"]) -> "BiPredicate"["T", "U"]:
        """
        Returns a composed predicate that represents a short-circuiting logical
        AND of this predicate and another.  When evaluating the composed
        predicate, if this predicate is `False`, then the `other`
        predicate is not evaluated.
        
        Any exceptions thrown during evaluation of either predicate are relayed
        to the caller; if evaluation of this predicate throws an exception, the
        `other` predicate will not be evaluated.

        Arguments
        - other: a predicate that will be logically-ANDed with this
                     predicate

        Returns
        - a composed predicate that represents the short-circuiting logical
        AND of this predicate and the `other` predicate

        Raises
        - NullPointerException: if other is null
        """
        ...


    def negate(self) -> "BiPredicate"["T", "U"]:
        """
        Returns a predicate that represents the logical negation of this
        predicate.

        Returns
        - a predicate that represents the logical negation of this
        predicate
        """
        ...


    def or(self, other: "BiPredicate"["T", "U"]) -> "BiPredicate"["T", "U"]:
        """
        Returns a composed predicate that represents a short-circuiting logical
        OR of this predicate and another.  When evaluating the composed
        predicate, if this predicate is `True`, then the `other`
        predicate is not evaluated.
        
        Any exceptions thrown during evaluation of either predicate are relayed
        to the caller; if evaluation of this predicate throws an exception, the
        `other` predicate will not be evaluated.

        Arguments
        - other: a predicate that will be logically-ORed with this
                     predicate

        Returns
        - a composed predicate that represents the short-circuiting logical
        OR of this predicate and the `other` predicate

        Raises
        - NullPointerException: if other is null
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.SheepDyeWoolEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import DyeColor
from org.bukkit.entity import Player
from org.bukkit.entity import Sheep
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class SheepDyeWoolEvent(EntityEvent, Cancellable):
    """
    Called when a sheep's wool is dyed
    """

    def __init__(self, sheep: "Sheep", color: "DyeColor"):
        ...


    def __init__(self, sheep: "Sheep", color: "DyeColor", player: "Player"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getEntity(self) -> "Sheep":
        ...


    def getPlayer(self) -> "Player":
        """
        Returns the player dyeing the sheep, if available.

        Returns
        - player or null
        """
        ...


    def getColor(self) -> "DyeColor":
        """
        Gets the DyeColor the sheep is being dyed

        Returns
        - the DyeColor the sheep is being dyed
        """
        ...


    def setColor(self, color: "DyeColor") -> None:
        """
        Sets the DyeColor the sheep is being dyed

        Arguments
        - color: the DyeColor the sheep will be dyed
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file java.util.function.DoubleBinaryOperator

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.function import *
from typing import Any, Callable, Iterable, Tuple


class DoubleBinaryOperator:
    """
    Represents an operation upon two `double`-valued operands and producing a
    `double`-valued result.   This is the primitive type specialization of
    BinaryOperator for `double`.
    
    This is a <a href="package-summary.html">functional interface</a>
    whose functional method is .applyAsDouble(double, double).

    See
    - DoubleUnaryOperator

    Since
    - 1.8
    """

    def applyAsDouble(self, left: float, right: float) -> float:
        """
        Applies this operator to the given operands.

        Arguments
        - left: the first operand
        - right: the second operand

        Returns
        - the operator result
        """
        ...



"""
Python module generated from Java source file com.google.gson.internal.bind.JsonAdapterAnnotationTypeAdapterFactory

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Gson
from com.google.gson import JsonDeserializer
from com.google.gson import JsonSerializer
from com.google.gson import TypeAdapter
from com.google.gson import TypeAdapterFactory
from com.google.gson.annotations import JsonAdapter
from com.google.gson.internal import ConstructorConstructor
from com.google.gson.internal.bind import *
from com.google.gson.reflect import TypeToken
from java.util import Objects
from java.util.concurrent import ConcurrentHashMap
from java.util.concurrent import ConcurrentMap
from typing import Any, Callable, Iterable, Tuple


class JsonAdapterAnnotationTypeAdapterFactory(TypeAdapterFactory):
    """
    Given a type T, looks for the annotation JsonAdapter and uses an instance of the
    specified class as the default type adapter.

    Since
    - 2.3
    """

    def __init__(self, constructorConstructor: "ConstructorConstructor"):
        ...


    def create(self, gson: "Gson", targetType: "TypeToken"["T"]) -> "TypeAdapter"["T"]:
        ...


    def isClassJsonAdapterFactory(self, type: "TypeToken"[Any], factory: "TypeAdapterFactory") -> bool:
        """
        Returns whether `factory` is a type adapter factory created for `@JsonAdapter`
        placed on `type`.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.DescendingMultiset

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import WeakOuter
from java.util import Comparator
from java.util import Iterator
from java.util import NavigableSet
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class DescendingMultiset(ForwardingMultiset, SortedMultiset):
    """
    A skeleton implementation of a descending multiset. Only needs `forwardMultiset()` and
    `entryIterator()`.

    Author(s)
    - Louis Wasserman
    """

    def comparator(self) -> "Comparator"["E"]:
        ...


    def elementSet(self) -> "NavigableSet"["E"]:
        ...


    def pollFirstEntry(self) -> "Entry"["E"]:
        ...


    def pollLastEntry(self) -> "Entry"["E"]:
        ...


    def headMultiset(self, toElement: "E", boundType: "BoundType") -> "SortedMultiset"["E"]:
        ...


    def subMultiset(self, fromElement: "E", fromBoundType: "BoundType", toElement: "E", toBoundType: "BoundType") -> "SortedMultiset"["E"]:
        ...


    def tailMultiset(self, fromElement: "E", boundType: "BoundType") -> "SortedMultiset"["E"]:
        ...


    def descendingMultiset(self) -> "SortedMultiset"["E"]:
        ...


    def firstEntry(self) -> "Entry"["E"]:
        ...


    def lastEntry(self) -> "Entry"["E"]:
        ...


    def entrySet(self) -> set["Entry"["E"]]:
        ...


    def iterator(self) -> Iterator["E"]:
        ...


    def toArray(self) -> list["Object"]:
        ...


    def toArray(self, array: list["T"]) -> list["T"]:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file com.google.common.reflect.Reflection

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.reflect import *
from java.lang.reflect import InvocationHandler
from java.lang.reflect import Proxy
from typing import Any, Callable, Iterable, Tuple


class Reflection:
    """
    Static utilities relating to Java reflection.

    Since
    - 12.0
    """

    @staticmethod
    def getPackageName(clazz: type[Any]) -> str:
        """
        Returns the package name of `clazz` according to the Java Language Specification (section
        6.7). Unlike Class.getPackage, this method only parses the class name, without
        attempting to define the Package and hence load files.
        """
        ...


    @staticmethod
    def getPackageName(classFullName: str) -> str:
        """
        Returns the package name of `classFullName` according to the Java Language Specification
        (section 6.7). Unlike Class.getPackage, this method only parses the class name, without
        attempting to define the Package and hence load files.
        """
        ...


    @staticmethod
    def initialize(*classes: Tuple[type[Any], ...]) -> None:
        """
        Ensures that the given classes are initialized, as described in <a
        href="http://java.sun.com/docs/books/jls/third_edition/html/execution.html#12.4.2">JLS Section
        12.4.2</a>.
        
        WARNING: Normally it's a smell if a class needs to be explicitly initialized, because static
        state hurts system maintainability and testability. In cases when you have no choice while
        interoperating with a legacy framework, this method helps to keep the code less ugly.

        Raises
        - ExceptionInInitializerError: if an exception is thrown during initialization of a class
        """
        ...


    @staticmethod
    def newProxy(interfaceType: type["T"], handler: "InvocationHandler") -> "T":
        """
        Returns a proxy instance that implements `interfaceType` by dispatching method
        invocations to `handler`. The class loader of `interfaceType` will be used to
        define the proxy class. To implement multiple interfaces or specify a class loader, use Proxy.newProxyInstance.

        Raises
        - IllegalArgumentException: if `interfaceType` does not specify the type of a Java
            interface
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.CreakingHeart

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Orientable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class CreakingHeart(Orientable):
    """
    'active' is whether the block is active.
    
    'natural' is whether this is a naturally generated block.
    """

    def isActive(self) -> bool:
        """
        Gets the value of the 'active' property.

        Returns
        - the 'active' value
        """
        ...


    def setActive(self, active: bool) -> None:
        """
        Sets the value of the 'active' property.

        Arguments
        - active: the new 'active' value
        """
        ...


    def isNatural(self) -> bool:
        """
        Gets the value of the 'natural' property.

        Returns
        - the 'natural' value
        """
        ...


    def setNatural(self, natural: bool) -> None:
        """
        Sets the value of the 'natural' property.

        Arguments
        - natural: the new 'natural' value
        """
        ...



"""
Python module generated from Java source file org.bukkit.util.StringUtil

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from org.bukkit.util import *
from typing import Any, Callable, Iterable, Tuple


class StringUtil:

    @staticmethod
    def copyPartialMatches(token: str, originals: Iterable[str], collection: "T") -> "T":
        """
        Copies all elements from the iterable collection of originals to the
        collection provided.
        
        Type `<T>`: the collection of strings

        Arguments
        - token: String to search for
        - originals: An iterable collection of strings to filter.
        - collection: The collection to add matches to

        Returns
        - the collection provided that would have the elements copied
            into

        Raises
        - UnsupportedOperationException: if the collection is immutable
            and originals contains a string which starts with the specified
            search string.
        - IllegalArgumentException: if any parameter is is null
        - IllegalArgumentException: if originals contains a null element.
            **Note: the collection may be modified before this is thrown**
        """
        ...


    @staticmethod
    def startsWithIgnoreCase(string: str, prefix: str) -> bool:
        """
        This method uses a region to check case-insensitive equality. This
        means the internal array does not need to be copied like a
        toLowerCase() call would.

        Arguments
        - string: String to check
        - prefix: Prefix of string to compare

        Returns
        - True if provided string starts with, ignoring case, the prefix
            provided

        Raises
        - NullPointerException: if prefix is null
        - IllegalArgumentException: if string is null
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.scanner.SimpleKey

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.scanner import *
from typing import Any, Callable, Iterable, Tuple


class SimpleKey:
    """
    Simple keys treatment.
    
    Helper class for ScannerImpl.

    See
    - ScannerImpl
    """

    def __init__(self, tokenNumber: int, required: bool, index: int, line: int, column: int, mark: "Mark"):
        ...


    def getTokenNumber(self) -> int:
        ...


    def getColumn(self) -> int:
        ...


    def getMark(self) -> "Mark":
        ...


    def getIndex(self) -> int:
        ...


    def getLine(self) -> int:
        ...


    def isRequired(self) -> bool:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.entity.WitherSkull

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class WitherSkull(Fireball):
    """
    Represents a wither skull Fireball.
    """

    def setCharged(self, charged: bool) -> None:
        """
        Sets the charged status of the wither skull.

        Arguments
        - charged: whether it should be charged
        """
        ...


    def isCharged(self) -> bool:
        """
        Gets whether or not the wither skull is charged.

        Returns
        - whether the wither skull is charged
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Raider

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Raid
from org.bukkit import Sound
from org.bukkit.block import Block
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Raider(Monster):

    def setRaid(self, raid: "Raid") -> None:
        """
        Set the Raid that this raider is participating in.

        Arguments
        - raid: the raid to set
        """
        ...


    def getRaid(self) -> "Raid":
        """
        Get the Raid that this raider is participating in, if any.

        Returns
        - the raid, or null if not participating in a raid
        """
        ...


    def getWave(self) -> int:
        """
        Get the raid wave that this raider spawned as part of.

        Returns
        - the raid wave, or 0 if not participating in a raid
        """
        ...


    def setWave(self, wave: int) -> None:
        """
        Set the raid wave that this raider was spawned as part of.

        Arguments
        - wave: the raid wave to set. Must be >= 0
        """
        ...


    def getPatrolTarget(self) -> "Block":
        """
        Gets the block the raider is targeting to patrol.

        Returns
        - target block or null
        """
        ...


    def setPatrolTarget(self, block: "Block") -> None:
        """
        Sets the block the raider is targeting to patrol.

        Arguments
        - block: target block or null. Must be in same world as the entity
        """
        ...


    def isPatrolLeader(self) -> bool:
        """
        Gets whether this entity is a patrol leader.

        Returns
        - patrol leader status
        """
        ...


    def setPatrolLeader(self, leader: bool) -> None:
        """
        Sets whether this entity is a patrol leader.

        Arguments
        - leader: patrol leader status
        """
        ...


    def isCanJoinRaid(self) -> bool:
        """
        Gets whether this mob can join an active raid.

        Returns
        - CanJoinRaid status
        """
        ...


    def setCanJoinRaid(self, join: bool) -> None:
        """
        Sets whether this mob can join an active raid.

        Arguments
        - join: CanJoinRaid status
        """
        ...


    def getTicksOutsideRaid(self) -> int:
        """
        Get the amount of ticks that this mob has exited the bounds of a village
        as a raid participant.
        
        This value is increased only when the mob has had no action for 2,400 ticks
        (according to .getNoActionTicks()). Once both the no action ticks have
        reached that value and the ticks outside a raid exceeds 30, the mob will be
        expelled from the raid.

        Returns
        - the ticks outside of a raid
        """
        ...


    def setTicksOutsideRaid(self, ticks: int) -> None:
        """
        Set the amount of ticks that this mob has exited the bounds of a village
        as a raid participant.
        
        This value is considered only when the mob has had no action for 2,400 ticks
        (according to .getNoActionTicks()). Once both the no action ticks have
        reached that value and the ticks outside a raid exceeds 30, the mob will be
        expelled from the raid.

        Arguments
        - ticks: the ticks outside of a raid
        """
        ...


    def isCelebrating(self) -> bool:
        """
        Check whether or not this raider is celebrating a raid victory.

        Returns
        - True if celebrating, False otherwise
        """
        ...


    def setCelebrating(self, celebrating: bool) -> None:
        """
        Set whether or not this mob is celebrating a raid victory.

        Arguments
        - celebrating: whether or not to celebrate
        """
        ...


    def getCelebrationSound(self) -> "Sound":
        """
        Get the Sound this entity will play when celebrating.

        Returns
        - the celebration sound
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.Cancellable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.event import *
from typing import Any, Callable, Iterable, Tuple


class Cancellable:
    """
    A type characterizing events that may be cancelled by a plugin or the server.
    """

    def isCancelled(self) -> bool:
        """
        Gets the cancellation state of this event. A cancelled event will not
        be executed in the server, but will still pass to other plugins

        Returns
        - True if this event is cancelled
        """
        ...


    def setCancelled(self, cancel: bool) -> None:
        """
        Sets the cancellation state of this event. A cancelled event will not
        be executed in the server, but will still pass to other plugins.

        Arguments
        - cancel: True if you wish to cancel this event
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.reader.UnicodeReader

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from java.io import InputStream
from java.io import InputStreamReader
from java.io import PushbackInputStream
from java.io import Reader
from java.nio.charset import Charset
from java.nio.charset import CharsetDecoder
from java.nio.charset import CodingErrorAction
from java.nio.charset import StandardCharsets
from org.yaml.snakeyaml.reader import *
from typing import Any, Callable, Iterable, Tuple


class UnicodeReader(Reader):
    """
    Generic unicode textreader, which will use BOM mark to identify the encoding to be used. If BOM
    is not found then use a given default or system encoding.
    """

    def __init__(self, in: "InputStream"):
        """
        Arguments
        - in: InputStream to be read
        """
        ...


    def getEncoding(self) -> str:
        """
        Get stream encoding or NULL if stream is uninitialized. Call init() or read() method to
        initialize it.

        Returns
        - the name of the character encoding being used by this stream.
        """
        ...


    def close(self) -> None:
        ...


    def read(self, cbuf: list[str], off: int, len: int) -> int:
        ...



from .SqlTypesSupport import SqlTypesSupport
from .SqlTimestampTypeAdapter import SqlTimestampTypeAdapter
from .SqlTimeTypeAdapter import SqlTimeTypeAdapter
from .SqlDateTypeAdapter import SqlDateTypeAdapter


"""
Python module generated from Java source file java.util.Optional

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from java.util.function import Consumer
from java.util.function import Function
from java.util.function import Predicate
from java.util.function import Supplier
from java.util.stream import Stream
from typing import Any, Callable, Iterable, Tuple


class Optional:
    """
    A container object which may or may not contain a non-`null` value.
    If a value is present, `isPresent()` returns `True`. If no
    value is present, the object is considered *empty* and
    `isPresent()` returns `False`.
    
    Additional methods that depend on the presence or absence of a contained
    value are provided, such as .orElse(Object) orElse()
    (returns a default value if no value is present) and
    .ifPresent(Consumer) ifPresent() (performs an
    action if a value is present).
    
    This is a <a href="/java.base/java/lang/doc-files/ValueBased.html">value-based</a>
    class; programmers should treat instances that are
    .equals(Object) equal as interchangeable and should not
    use instances for synchronization, or unpredictable behavior may
    occur. For example, in a future release, synchronization may fail.
    
    Type `<T>`: the type of value

    Since
    - 1.8

    Unknown Tags
    - `Optional` is primarily intended for use as a method return type where
    there is a clear need to represent "no result," and where using `null`
    is likely to cause errors. A variable whose type is `Optional` should
    never itself be `null`; it should always point to an `Optional`
    instance.
    """

    @staticmethod
    def empty() -> "Optional"["T"]:
        """
        Returns an empty `Optional` instance.  No value is present for this
        `Optional`.
        
        Type `<T>`: The type of the non-existent value

        Returns
        - an empty `Optional`

        Unknown Tags
        - Though it may be tempting to do so, avoid testing if an object is empty
        by comparing with `==` or `!=` against instances returned by
        `Optional.empty()`.  There is no guarantee that it is a singleton.
        Instead, use .isEmpty() or .isPresent().
        """
        ...


    @staticmethod
    def of(value: "T") -> "Optional"["T"]:
        """
        Returns an `Optional` describing the given non-`null`
        value.
        
        Type `<T>`: the type of the value

        Arguments
        - value: the value to describe, which must be non-`null`

        Returns
        - an `Optional` with the value present

        Raises
        - NullPointerException: if value is `null`
        """
        ...


    @staticmethod
    def ofNullable(value: "T") -> "Optional"["T"]:
        """
        Returns an `Optional` describing the given value, if
        non-`null`, otherwise returns an empty `Optional`.
        
        Type `<T>`: the type of the value

        Arguments
        - value: the possibly-`null` value to describe

        Returns
        - an `Optional` with a present value if the specified value
                is non-`null`, otherwise an empty `Optional`
        """
        ...


    def get(self) -> "T":
        """
        If a value is present, returns the value, otherwise throws
        `NoSuchElementException`.

        Returns
        - the non-`null` value described by this `Optional`

        Raises
        - NoSuchElementException: if no value is present

        Unknown Tags
        - The preferred alternative to this method is .orElseThrow().
        """
        ...


    def isPresent(self) -> bool:
        """
        If a value is present, returns `True`, otherwise `False`.

        Returns
        - `True` if a value is present, otherwise `False`
        """
        ...


    def isEmpty(self) -> bool:
        """
        If a value is  not present, returns `True`, otherwise
        `False`.

        Returns
        - `True` if a value is not present, otherwise `False`

        Since
        - 11
        """
        ...


    def ifPresent(self, action: "Consumer"["T"]) -> None:
        """
        If a value is present, performs the given action with the value,
        otherwise does nothing.

        Arguments
        - action: the action to be performed, if a value is present

        Raises
        - NullPointerException: if value is present and the given action is
                `null`
        """
        ...


    def ifPresentOrElse(self, action: "Consumer"["T"], emptyAction: "Runnable") -> None:
        """
        If a value is present, performs the given action with the value,
        otherwise performs the given empty-based action.

        Arguments
        - action: the action to be performed, if a value is present
        - emptyAction: the empty-based action to be performed, if no value is
               present

        Raises
        - NullPointerException: if a value is present and the given action
                is `null`, or no value is present and the given empty-based
                action is `null`.

        Since
        - 9
        """
        ...


    def filter(self, predicate: "Predicate"["T"]) -> "Optional"["T"]:
        """
        If a value is present, and the value matches the given predicate,
        returns an `Optional` describing the value, otherwise returns an
        empty `Optional`.

        Arguments
        - predicate: the predicate to apply to a value, if present

        Returns
        - an `Optional` describing the value of this
                `Optional`, if a value is present and the value matches the
                given predicate, otherwise an empty `Optional`

        Raises
        - NullPointerException: if the predicate is `null`
        """
        ...


    def map(self, mapper: "Function"["T", "U"]) -> "Optional"["U"]:
        """
        If a value is present, returns an `Optional` describing (as if by
        .ofNullable) the result of applying the given mapping function to
        the value, otherwise returns an empty `Optional`.
        
        If the mapping function returns a `null` result then this method
        returns an empty `Optional`.
        
        Type `<U>`: The type of the value returned from the mapping function

        Arguments
        - mapper: the mapping function to apply to a value, if present

        Returns
        - an `Optional` describing the result of applying a mapping
                function to the value of this `Optional`, if a value is
                present, otherwise an empty `Optional`

        Raises
        - NullPointerException: if the mapping function is `null`

        Unknown Tags
        - This method supports post-processing on `Optional` values, without
        the need to explicitly check for a return status.  For example, the
        following code traverses a stream of URIs, selects one that has not
        yet been processed, and creates a path from that URI, returning
        an `Optional<Path>`:
        
        ````Optional<Path> p =
                uris.stream().filter(uri -> !isProcessedYet(uri))
                              .findFirst()
                              .map(Paths::get);````
        
        Here, `findFirst` returns an `Optional<URI>`, and then
        `map` returns an `Optional<Path>` for the desired
        URI if one exists.
        """
        ...


    def flatMap(self, mapper: "Function"["T", "Optional"["U"]]) -> "Optional"["U"]:
        """
        If a value is present, returns the result of applying the given
        `Optional`-bearing mapping function to the value, otherwise returns
        an empty `Optional`.
        
        This method is similar to .map(Function), but the mapping
        function is one whose result is already an `Optional`, and if
        invoked, `flatMap` does not wrap it within an additional
        `Optional`.
        
        Type `<U>`: The type of value of the `Optional` returned by the
                   mapping function

        Arguments
        - mapper: the mapping function to apply to a value, if present

        Returns
        - the result of applying an `Optional`-bearing mapping
                function to the value of this `Optional`, if a value is
                present, otherwise an empty `Optional`

        Raises
        - NullPointerException: if the mapping function is `null` or
                returns a `null` result
        """
        ...


    def or(self, supplier: "Supplier"["Optional"["T"]]) -> "Optional"["T"]:
        """
        If a value is present, returns an `Optional` describing the value,
        otherwise returns an `Optional` produced by the supplying function.

        Arguments
        - supplier: the supplying function that produces an `Optional`
               to be returned

        Returns
        - returns an `Optional` describing the value of this
                `Optional`, if a value is present, otherwise an
                `Optional` produced by the supplying function.

        Raises
        - NullPointerException: if the supplying function is `null` or
                produces a `null` result

        Since
        - 9
        """
        ...


    def stream(self) -> "Stream"["T"]:
        """
        If a value is present, returns a sequential Stream containing
        only that value, otherwise returns an empty `Stream`.

        Returns
        - the optional value as a `Stream`

        Since
        - 9

        Unknown Tags
        - This method can be used to transform a `Stream` of optional
        elements to a `Stream` of present value elements:
        ````Stream<Optional<T>> os = ..
            Stream<T> s = os.flatMap(Optional::stream)````
        """
        ...


    def orElse(self, other: "T") -> "T":
        """
        If a value is present, returns the value, otherwise returns
        `other`.

        Arguments
        - other: the value to be returned, if no value is present.
               May be `null`.

        Returns
        - the value, if present, otherwise `other`
        """
        ...


    def orElseGet(self, supplier: "Supplier"["T"]) -> "T":
        """
        If a value is present, returns the value, otherwise returns the result
        produced by the supplying function.

        Arguments
        - supplier: the supplying function that produces a value to be returned

        Returns
        - the value, if present, otherwise the result produced by the
                supplying function

        Raises
        - NullPointerException: if no value is present and the supplying
                function is `null`
        """
        ...


    def orElseThrow(self) -> "T":
        """
        If a value is present, returns the value, otherwise throws
        `NoSuchElementException`.

        Returns
        - the non-`null` value described by this `Optional`

        Raises
        - NoSuchElementException: if no value is present

        Since
        - 10
        """
        ...


    def orElseThrow(self, exceptionSupplier: "Supplier"["X"]) -> "T":
        """
        If a value is present, returns the value, otherwise throws an exception
        produced by the exception supplying function.
        
        Type `<X>`: Type of the exception to be thrown

        Arguments
        - exceptionSupplier: the supplying function that produces an
               exception to be thrown

        Returns
        - the value, if present

        Raises
        - X: if no value is present
        - NullPointerException: if no value is present and the exception
                 supplying function is `null`

        Unknown Tags
        - A method reference to the exception constructor with an empty argument
        list can be used as the supplier. For example,
        `IllegalStateException::new`
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Indicates whether some other object is "equal to" this `Optional`.
        The other object is considered equal if:
        
        - it is also an `Optional` and;
        - both instances have no value present or;
        - the present values are "equal to" each other via `equals()`.

        Arguments
        - obj: an object to be tested for equality

        Returns
        - `True` if the other object is "equal to" this object
                otherwise `False`
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code of the value, if present, otherwise `0`
        (zero) if no value is present.

        Returns
        - hash code value of the present value or `0` if no value is
                present
        """
        ...


    def toString(self) -> str:
        """
        Returns a non-empty string representation of this `Optional`
        suitable for debugging.  The exact presentation format is unspecified and
        may vary between implementations and versions.

        Returns
        - the string representation of this instance

        Unknown Tags
        - If a value is present the result must include its string representation
        in the result.  Empty and present `Optional`s must be unambiguously
        differentiable.
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.Banner

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import DyeColor
from org.bukkit.block import *
from org.bukkit.block.banner import Pattern
from typing import Any, Callable, Iterable, Tuple


class Banner(TileState):
    """
    Represents a captured state of a banner.
    """

    def getBaseColor(self) -> "DyeColor":
        """
        Returns the base color for this banner

        Returns
        - the base color
        """
        ...


    def setBaseColor(self, color: "DyeColor") -> None:
        """
        Sets the base color for this banner.
        **Only valid for shield pseudo banners, otherwise base depends on block
        type**

        Arguments
        - color: the base color
        """
        ...


    def getPatterns(self) -> list["Pattern"]:
        """
        Returns a list of patterns on this banner

        Returns
        - the patterns
        """
        ...


    def setPatterns(self, patterns: list["Pattern"]) -> None:
        """
        Sets the patterns used on this banner

        Arguments
        - patterns: the new list of patterns
        """
        ...


    def addPattern(self, pattern: "Pattern") -> None:
        """
        Adds a new pattern on top of the existing
        patterns

        Arguments
        - pattern: the new pattern to add
        """
        ...


    def getPattern(self, i: int) -> "Pattern":
        """
        Returns the pattern at the specified index

        Arguments
        - i: the index

        Returns
        - the pattern
        """
        ...


    def removePattern(self, i: int) -> "Pattern":
        """
        Removes the pattern at the specified index

        Arguments
        - i: the index

        Returns
        - the removed pattern
        """
        ...


    def setPattern(self, i: int, pattern: "Pattern") -> None:
        """
        Sets the pattern at the specified index

        Arguments
        - i: the index
        - pattern: the new pattern
        """
        ...


    def numberOfPatterns(self) -> int:
        """
        Returns the number of patterns on this
        banner

        Returns
        - the number of patterns
        """
        ...



"""
Python module generated from Java source file java.util.jar.JarFile

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import ByteArrayInputStream
from java.io import EOFException
from java.io import File
from java.io import IOException
from java.io import InputStream
from java.lang.ref import SoftReference
from java.net import URL
from java.security import CodeSigner
from java.security import CodeSource
from java.security.cert import Certificate
from java.util import Collections
from java.util import Enumeration
from java.util import Locale
from java.util import NoSuchElementException
from java.util import Objects
from java.util.function import Function
from java.util.jar import *
from java.util.stream import Stream
from java.util.zip import ZipEntry
from java.util.zip import ZipException
from java.util.zip import ZipFile
from jdk.internal.access import JavaUtilZipFileAccess
from jdk.internal.access import SharedSecrets
from sun.security.action import GetPropertyAction
from sun.security.util import ManifestEntryVerifier
from typing import Any, Callable, Iterable, Tuple


class JarFile(ZipFile):
    """
    The `JarFile` class is used to read the contents of a jar file
    from any file that can be opened with `java.io.RandomAccessFile`.
    It extends the class `java.util.zip.ZipFile` with support
    for reading an optional `Manifest` entry, and support for
    processing multi-release jar files.  The `Manifest` can be used
    to specify meta-information about the jar file and its entries.
    
    <a id="multirelease">A multi-release jar file</a> is a jar file that
    contains a manifest with a main attribute named "Multi-Release",
    a set of "base" entries, some of which are public classes with public
    or protected methods that comprise the public interface of the jar file,
    and a set of "versioned" entries contained in subdirectories of the
    "META-INF/versions" directory.  The versioned entries are partitioned by the
    major version of the Java platform.  A versioned entry, with a version
    `n`, `8 < n`, in the "META-INF/versions/{n}" directory overrides
    the base entry as well as any entry with a version number `i` where
    `8 < i < n`.
    
    By default, a `JarFile` for a multi-release jar file is configured
    to process the multi-release jar file as if it were a plain (unversioned) jar
    file, and as such an entry name is associated with at most one base entry.
    The `JarFile` may be configured to process a multi-release jar file by
    creating the `JarFile` with the
    JarFile.JarFile(File, boolean, int, Runtime.Version) constructor.  The
    `Runtime.Version` object sets a maximum version used when searching for
    versioned entries.  When so configured, an entry name
    can correspond with at most one base entry and zero or more versioned
    entries. A search is required to associate the entry name with the latest
    versioned entry whose version is less than or equal to the maximum version
    (see .getEntry(String)).
    
    Class loaders that utilize `JarFile` to load classes from the
    contents of `JarFile` entries should construct the `JarFile`
    by invoking the JarFile.JarFile(File, boolean, int, Runtime.Version)
    constructor with the value `Runtime.version()` assigned to the last
    argument.  This assures that classes compatible with the major
    version of the running JVM are loaded from multi-release jar files.
    
     If the `verify` flag is on when opening a signed jar file, the content
    of the jar entry is verified against the signature embedded inside the manifest
    that is associated with its JarEntry.getRealName() path name. For a
    multi-release jar file, the content of a versioned entry is verfieid against
    its own signature and JarEntry.getCodeSigners() returns its own signers.
    
    Please note that the verification process does not include validating the
    signer's certificate. A caller should inspect the return value of
    JarEntry.getCodeSigners() to further determine if the signature
    can be trusted.
    
     Unless otherwise noted, passing a `null` argument to a constructor
    or method in this class will cause a NullPointerException to be
    thrown.

    Author(s)
    - David Connelly

    See
    - java.util.jar.JarEntry

    Since
    - 1.2

    Unknown Tags
    - <div class="block">
    If the API can not be used to configure a `JarFile` (e.g. to override
    the configuration of a compiled application or library), two `System`
    properties are available.
    
    - 
    `jdk.util.jar.version` can be assigned a value that is the
    `String` representation of a non-negative integer
    `<= Runtime.version().feature()`.  The value is used to set the effective
    runtime version to something other than the default value obtained by
    evaluating `Runtime.version().feature()`. The effective runtime version
    is the version that the JarFile.JarFile(File, boolean, int, Runtime.Version)
    constructor uses when the value of the last argument is
    `JarFile.runtimeVersion()`.
    
    - 
    `jdk.util.jar.enableMultiRelease` can be assigned one of the three
    `String` values *True*, *False*, or *force*.  The
    value *True*, the default value, enables multi-release jar file
    processing.  The value *False* disables multi-release jar processing,
    ignoring the "Multi-Release" manifest attribute, and the versioned
    directories in a multi-release jar file if they exist.  Furthermore,
    the method JarFile.isMultiRelease() returns *False*. The value
    *force* causes the `JarFile` to be initialized to runtime
    versioning after construction.  It effectively does the same as this code:
    `(new JarFile(File, boolean, int, JarFile.runtimeVersion())`.
    
    
    </div>
    """

    MANIFEST_NAME = META_INF + "MANIFEST.MF"
    """
    The JAR manifest file name.
    """


    def __init__(self, name: str):
        """
        Creates a new `JarFile` to read from the specified
        file `name`. The `JarFile` will be verified if
        it is signed.

        Arguments
        - name: the name of the jar file to be opened for reading

        Raises
        - IOException: if an I/O error has occurred
        - SecurityException: if access to the file is denied
                by the SecurityManager
        """
        ...


    def __init__(self, name: str, verify: bool):
        """
        Creates a new `JarFile` to read from the specified
        file `name`.

        Arguments
        - name: the name of the jar file to be opened for reading
        - verify: whether or not to verify the jar file if
        it is signed.

        Raises
        - IOException: if an I/O error has occurred
        - SecurityException: if access to the file is denied
                by the SecurityManager
        """
        ...


    def __init__(self, file: "File"):
        """
        Creates a new `JarFile` to read from the specified
        `File` object. The `JarFile` will be verified if
        it is signed.

        Arguments
        - file: the jar file to be opened for reading

        Raises
        - IOException: if an I/O error has occurred
        - SecurityException: if access to the file is denied
                by the SecurityManager
        """
        ...


    def __init__(self, file: "File", verify: bool):
        """
        Creates a new `JarFile` to read from the specified
        `File` object.

        Arguments
        - file: the jar file to be opened for reading
        - verify: whether or not to verify the jar file if
        it is signed.

        Raises
        - IOException: if an I/O error has occurred
        - SecurityException: if access to the file is denied
                by the SecurityManager.
        """
        ...


    def __init__(self, file: "File", verify: bool, mode: int):
        """
        Creates a new `JarFile` to read from the specified
        `File` object in the specified mode.  The mode argument
        must be either `OPEN_READ` or `OPEN_READ | OPEN_DELETE`.

        Arguments
        - file: the jar file to be opened for reading
        - verify: whether or not to verify the jar file if
        it is signed.
        - mode: the mode in which the file is to be opened

        Raises
        - IOException: if an I/O error has occurred
        - IllegalArgumentException: if the `mode` argument is invalid
        - SecurityException: if access to the file is denied
                by the SecurityManager

        Since
        - 1.3
        """
        ...


    def __init__(self, file: "File", verify: bool, mode: int, version: "Runtime.Version"):
        """
        Creates a new `JarFile` to read from the specified
        `File` object in the specified mode.  The mode argument
        must be either `OPEN_READ` or `OPEN_READ | OPEN_DELETE`.
        The version argument, after being converted to a canonical form, is
        used to configure the `JarFile` for processing
        multi-release jar files.
        
        The canonical form derived from the version parameter is
        `Runtime.Version.parse(Integer.toString(n))` where `n` is
        `Math.max(version.feature(), JarFile.baseVersion().feature())`.

        Arguments
        - file: the jar file to be opened for reading
        - verify: whether or not to verify the jar file if
        it is signed.
        - mode: the mode in which the file is to be opened
        - version: specifies the release version for a multi-release jar file

        Raises
        - IOException: if an I/O error has occurred
        - IllegalArgumentException: if the `mode` argument is invalid
        - SecurityException: if access to the file is denied
                by the SecurityManager
        - NullPointerException: if `version` is `null`

        Since
        - 9
        """
        ...


    @staticmethod
    def baseVersion() -> "Runtime.Version":
        """
        Returns the version that represents the unversioned configuration of a
        multi-release jar file.

        Returns
        - the version that represents the unversioned configuration

        Since
        - 9
        """
        ...


    @staticmethod
    def runtimeVersion() -> "Runtime.Version":
        """
        Returns the version that represents the effective runtime versioned
        configuration of a multi-release jar file.
        
        By default the feature version number of the returned `Version` will
        be equal to the feature version number of `Runtime.version()`.
        However, if the `jdk.util.jar.version` property is set, the
        returned `Version` is derived from that property and feature version
        numbers may not be equal.

        Returns
        - the version that represents the runtime versioned configuration

        Since
        - 9
        """
        ...


    def getVersion(self) -> "Runtime.Version":
        """
        Returns the maximum version used when searching for versioned entries.
        
        If this `JarFile` is not a multi-release jar file or is not
        configured to be processed as such, then the version returned will be the
        same as that returned from .baseVersion().

        Returns
        - the maximum version

        Since
        - 9
        """
        ...


    def isMultiRelease(self) -> bool:
        """
        Indicates whether or not this jar file is a multi-release jar file.

        Returns
        - True if this JarFile is a multi-release jar file

        Since
        - 9
        """
        ...


    def getManifest(self) -> "Manifest":
        """
        Returns the jar file manifest, or `null` if none.

        Returns
        - the jar file manifest, or `null` if none

        Raises
        - IllegalStateException: may be thrown if the jar file has been closed
        - IOException: if an I/O error has occurred
        """
        ...


    def getJarEntry(self, name: str) -> "JarEntry":
        """
        Returns the `JarEntry` for the given base entry name or
        `null` if not found.
        
        If this `JarFile` is a multi-release jar file and is configured
        to be processed as such, then a search is performed to find and return
        a `JarEntry` that is the latest versioned entry associated with the
        given entry name.  The returned `JarEntry` is the versioned entry
        corresponding to the given base entry name prefixed with the string
        `"META-INF/versions/{n`/"}, for the largest value of `n` for
        which an entry exists.  If such a versioned entry does not exist, then
        the `JarEntry` for the base entry is returned, otherwise
        `null` is returned if no entries are found.  The initial value for
        the version `n` is the maximum version as returned by the method
        JarFile.getVersion().

        Arguments
        - name: the jar file entry name

        Returns
        - the `JarEntry` for the given entry name, or
                the versioned entry name, or `null` if not found

        Raises
        - IllegalStateException: may be thrown if the jar file has been closed

        See
        - java.util.jar.JarEntry

        Unknown Tags
        - <div class="block">
        This implementation invokes JarFile.getEntry(String).
        </div>
        """
        ...


    def getEntry(self, name: str) -> "ZipEntry":
        """
        Returns the `ZipEntry` for the given base entry name or
        `null` if not found.
        
        If this `JarFile` is a multi-release jar file and is configured
        to be processed as such, then a search is performed to find and return
        a `ZipEntry` that is the latest versioned entry associated with the
        given entry name.  The returned `ZipEntry` is the versioned entry
        corresponding to the given base entry name prefixed with the string
        `"META-INF/versions/{n`/"}, for the largest value of `n` for
        which an entry exists.  If such a versioned entry does not exist, then
        the `ZipEntry` for the base entry is returned, otherwise
        `null` is returned if no entries are found.  The initial value for
        the version `n` is the maximum version as returned by the method
        JarFile.getVersion().

        Arguments
        - name: the jar file entry name

        Returns
        - the `ZipEntry` for the given entry name or
                the versioned entry name or `null` if not found

        Raises
        - IllegalStateException: may be thrown if the jar file has been closed

        See
        - java.util.zip.ZipEntry

        Unknown Tags
        - <div class="block">
        This implementation may return a versioned entry for the requested name
        even if there is not a corresponding base entry.  This can occur
        if there is a private or package-private versioned entry that matches.
        If a subclass overrides this method, assure that the override method
        invokes `super.getEntry(name)` to obtain all versioned entries.
        </div>
        """
        ...


    def entries(self) -> "Enumeration"["JarEntry"]:
        """
        Returns an enumeration of the jar file entries.

        Returns
        - an enumeration of the jar file entries

        Raises
        - IllegalStateException: may be thrown if the jar file has been closed
        """
        ...


    def stream(self) -> "Stream"["JarEntry"]:
        """
        Returns an ordered `Stream` over the jar file entries.
        Entries appear in the `Stream` in the order they appear in
        the central directory of the jar file.

        Returns
        - an ordered `Stream` of entries in this jar file

        Raises
        - IllegalStateException: if the jar file has been closed

        Since
        - 1.8
        """
        ...


    def versionedStream(self) -> "Stream"["JarEntry"]:
        """
        Returns a `Stream` of the versioned jar file entries.
        
        If this `JarFile` is a multi-release jar file and is configured to
        be processed as such, then an entry in the stream is the latest versioned entry
        associated with the corresponding base entry name. The maximum version of the
        latest versioned entry is the version returned by .getVersion().
        The returned stream may include an entry that only exists as a versioned entry.
        
        If the jar file is not a multi-release jar file or the `JarFile` is not
        configured for processing a multi-release jar file, this method returns the
        same stream that .stream() returns.

        Returns
        - stream of versioned entries

        Since
        - 10
        """
        ...


    def getInputStream(self, ze: "ZipEntry") -> "InputStream":
        """
        Returns an input stream for reading the contents of the specified
        zip file entry.

        Arguments
        - ze: the zip file entry

        Returns
        - an input stream for reading the contents of the specified
                zip file entry

        Raises
        - ZipException: if a zip file format error has occurred
        - IOException: if an I/O error has occurred
        - SecurityException: if any of the jar file entries
                are incorrectly signed.
        - IllegalStateException: may be thrown if the jar file has been closed
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.CompassMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.inventory.meta import *
from typing import Any, Callable, Iterable, Tuple


class CompassMeta(ItemMeta):
    """
    Represents a compass that can track a specific location.
    """

    def hasLodestone(self) -> bool:
        """
        Checks if this compass has been paired to a lodestone.

        Returns
        - paired status
        """
        ...


    def getLodestone(self) -> "Location":
        """
        Gets the location that this compass will point to.
        
        Check .hasLodestone() first!

        Returns
        - lodestone location
        """
        ...


    def setLodestone(self, lodestone: "Location") -> None:
        """
        Sets the location this lodestone compass will point to.

        Arguments
        - lodestone: new location or null to clear
        """
        ...


    def isLodestoneTracked(self) -> bool:
        """
        Gets if this compass is tracking a specific lodestone.
        
        If True the compass will only work if there is a lodestone at the tracked
        location.

        Returns
        - lodestone tracked
        """
        ...


    def setLodestoneTracked(self, tracked: bool) -> None:
        """
        Sets if this compass is tracking a specific lodestone.
        
        If True the compass will only work if there is a lodestone at the tracked
        location.

        Arguments
        - tracked: new tracked status
        """
        ...


    def clone(self) -> "CompassMeta":
        ...



from .TypeAdapters import TypeAdapters
from .TypeAdapterRuntimeTypeWrapper import TypeAdapterRuntimeTypeWrapper
from .TreeTypeAdapter import TreeTypeAdapter
from .SerializationDelegatingTypeAdapter import SerializationDelegatingTypeAdapter
from .ReflectiveTypeAdapterFactory import ReflectiveTypeAdapterFactory
from .ObjectTypeAdapter import ObjectTypeAdapter
from .NumberTypeAdapter import NumberTypeAdapter
from .MapTypeAdapterFactory import MapTypeAdapterFactory
from .JsonTreeWriter import JsonTreeWriter
from .JsonTreeReader import JsonTreeReader
from .JsonAdapterAnnotationTypeAdapterFactory import JsonAdapterAnnotationTypeAdapterFactory
from .DefaultDateTypeAdapter import DefaultDateTypeAdapter
from .CollectionTypeAdapterFactory import CollectionTypeAdapterFactory
from .ArrayTypeAdapter import ArrayTypeAdapter


"""
Python module generated from Java source file org.bukkit.plugin.SimpleServicesManager

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import ImmutableList
from com.google.common.collect import ImmutableSet
from java.util import Collections
from java.util import Iterator
from java.util import NoSuchElementException
from org.bukkit import Bukkit
from org.bukkit.event.server import ServiceRegisterEvent
from org.bukkit.event.server import ServiceUnregisterEvent
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class SimpleServicesManager(ServicesManager):
    """
    A simple services manager.
    """

    def register(self, service: type["T"], provider: "T", plugin: "Plugin", priority: "ServicePriority") -> None:
        """
        Register a provider of a service.
        
        Type `<T>`: Provider

        Arguments
        - service: service class
        - provider: provider to register
        - plugin: plugin with the provider
        - priority: priority of the provider
        """
        ...


    def unregisterAll(self, plugin: "Plugin") -> None:
        """
        Unregister all the providers registered by a particular plugin.

        Arguments
        - plugin: The plugin
        """
        ...


    def unregister(self, service: type[Any], provider: "Object") -> None:
        """
        Unregister a particular provider for a particular service.

        Arguments
        - service: The service interface
        - provider: The service provider implementation
        """
        ...


    def unregister(self, provider: "Object") -> None:
        """
        Unregister a particular provider.

        Arguments
        - provider: The service provider implementation
        """
        ...


    def load(self, service: type["T"]) -> "T":
        """
        Queries for a provider. This may return if no provider has been
        registered for a service. The highest priority provider is returned.
        
        Type `<T>`: The service interface

        Arguments
        - service: The service interface

        Returns
        - provider or null
        """
        ...


    def getRegistration(self, service: type["T"]) -> "RegisteredServiceProvider"["T"]:
        """
        Queries for a provider registration. This may return if no provider
        has been registered for a service.
        
        Type `<T>`: The service interface

        Arguments
        - service: The service interface

        Returns
        - provider registration or null
        """
        ...


    def getRegistrations(self, plugin: "Plugin") -> list["RegisteredServiceProvider"[Any]]:
        """
        Get registrations of providers for a plugin.

        Arguments
        - plugin: The plugin

        Returns
        - provider registrations
        """
        ...


    def getRegistrations(self, service: type["T"]) -> list["RegisteredServiceProvider"["T"]]:
        """
        Get registrations of providers for a service. The returned list is
        an unmodifiable copy.
        
        Type `<T>`: The service interface

        Arguments
        - service: The service interface

        Returns
        - a copy of the list of registrations
        """
        ...


    def getKnownServices(self) -> set[type[Any]]:
        """
        Get a list of known services. A service is known if it has registered
        providers for it.

        Returns
        - a copy of the set of known services
        """
        ...


    def isProvidedFor(self, service: type["T"]) -> bool:
        """
        Returns whether a provider has been registered for a service.
        
        Type `<T>`: service

        Arguments
        - service: service to check

        Returns
        - True if and only if there are registered providers
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.AnimalTamer

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import UUID
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class AnimalTamer:

    def getName(self) -> str:
        """
        This is the name of the specified AnimalTamer.

        Returns
        - The name to reference on tamed animals or null if a name cannot be obtained
        """
        ...


    def getUniqueId(self) -> "UUID":
        """
        This is the UUID of the specified AnimalTamer.

        Returns
        - The UUID to reference on tamed animals
        """
        ...



from .ServiceUnregisterEvent import ServiceUnregisterEvent
from .ServerListPingEvent import ServerListPingEvent
from .ServerCommandEvent import ServerCommandEvent
from .ServiceEvent import ServiceEvent
from .TabCompleteEvent import TabCompleteEvent
from .BroadcastMessageEvent import BroadcastMessageEvent
from .ServiceRegisterEvent import ServiceRegisterEvent
from .ServerEvent import ServerEvent
from .ServerLoadEvent import ServerLoadEvent
from .PluginEnableEvent import PluginEnableEvent
from .PluginEvent import PluginEvent
from .RemoteServerCommandEvent import RemoteServerCommandEvent
from .MapInitializeEvent import MapInitializeEvent
from .PluginDisableEvent import PluginDisableEvent